@@ -45,54 +45,53 @@
 extern queue<XCVR_STATE> queA;
 extern queue<XCVR_STATE> queB;
 
-void read_K3()
+void read_K3_vfo()
 {
-	guard_lock serial_lock(&mutex_serial);
-
-	if (progStatus.poll_frequency) {
-		unsigned long int freq;
-		freq = selrig->get_vfoA();
-		if (freq != vfoA.freq) {
-			vfoA.freq = freq;
-			Fl::awake(setFreqDispA, (void *)vfoA.freq);
-			vfo = &vfoA;
-		}
-		freq = selrig->get_vfoB();
-		if (freq != vfoB.freq) {
-			vfoB.freq = freq;
-			Fl::awake(setFreqDispB, (void *)vfoB.freq);
-		}
+	unsigned long int freq;
+	freq = selrig->get_vfoA();
+	if (freq != vfoA.freq) {
+		vfoA.freq = freq;
+		Fl::awake(setFreqDispA, (void *)vfoA.freq);
+		vfo = &vfoA;
 	}
-
-	if (progStatus.poll_mode) {
-		int nu_mode;
-		nu_mode = selrig->get_modeA();
-		if (nu_mode != vfoA.imode) {
-			vfoA.imode = vfo->imode = nu_mode;
-			selrig->set_bwA(vfo->iBW = selrig->adjust_bandwidth(nu_mode));
-			Fl::awake(setModeControl);
-			Fl::awake(updateBandwidthControl);
-		}
-		nu_mode = selrig->get_modeB();
-		if (nu_mode != vfoB.imode) {
-			vfoB.imode = nu_mode;
-		}
-	}
-
-	if (progStatus.poll_bandwidth) {
-		int nu_BW;
-		nu_BW = selrig->get_bwA();
-		if (nu_BW != vfoA.iBW) {
-			vfoA.iBW = vfo->iBW = nu_BW;
-			Fl::awake(setBWControl);
-		}
-		nu_BW = selrig->get_bwB();
-		if (nu_BW != vfoB.iBW) {
-			vfoB.iBW = nu_BW;
-		}
+	freq = selrig->get_vfoB();
+	if (freq != vfoB.freq) {
+		vfoB.freq = freq;
+		Fl::awake(setFreqDispB, (void *)vfoB.freq);
 	}
 }
 
+void read_K3_mode()
+{
+	int nu_mode;
+	nu_mode = selrig->get_modeA();
+	if (nu_mode != vfoA.imode) {
+		vfoA.imode = vfo->imode = nu_mode;
+		selrig->set_bwA(vfo->iBW = selrig->adjust_bandwidth(nu_mode));
+		Fl::awake(setModeControl);
+		Fl::awake(updateBandwidthControl);
+	}
+	nu_mode = selrig->get_modeB();
+	if (nu_mode != vfoB.imode) {
+		vfoB.imode = nu_mode;
+	}
+}
+
+void read_K3_bw()
+{
+	int nu_BW;
+	nu_BW = selrig->get_bwA();
+	if (nu_BW != vfoA.iBW) {
+		vfoA.iBW = vfo->iBW = nu_BW;
+		Fl::awake(setBWControl);
+	}
+	nu_BW = selrig->get_bwB();
+	if (nu_BW != vfoB.iBW) {
+		vfoB.iBW = nu_BW;
+	}
+}
+
+
 void K3_set_split(int val)
 {
 	guard_lock serial_lock(&mutex_serial);
@@ -119,11 +118,11 @@ void cb_K3_swapAB()
 	XCVR_STATE temp = vfoA;
 	vfoA = vfoB;
 	vfoB = temp;
-	vfo = &vfoA;
 
 	selrig->set_vfoB(vfoB.freq);
 	selrig->set_bwB(vfoB.iBW);
 	selrig->set_modeB(vfoB.imode);
+	FreqDispB->value(vfoB.freq);
 
 	selrig->set_vfoA(vfoA.freq);
 	selrig->set_bwA(vfoA.iBW);
@@ -133,7 +132,6 @@ void cb_K3_swapAB()
 	opMODE->index(vfoA.imode);
 	FreqDispA->value(vfoA.freq);
 
-	FreqDispB->value(vfoB.freq);
-
+	vfo = &vfoA;
 	Fl::focus(FreqDispA);
 }
