@@ -45,55 +45,53 @@
 extern queue<XCVR_STATE> queA;
 extern queue<XCVR_STATE> queB;
 
-void read_KX3()
+void read_KX3_vfo()
 {
-	guard_lock serial_lock(&mutex_serial);
-
-	if (progStatus.poll_frequency) {
-		unsigned long int freq;
-		freq = selrig->get_vfoA();
-		if (freq != vfoA.freq) {
-			vfoA.freq = freq;
-			Fl::awake(setFreqDispA, (void *)vfoA.freq);
-			vfo = &vfoA;
-		}
-		freq = selrig->get_vfoB();
-		if (freq != vfoB.freq) {
-			vfoB.freq = freq;
-			Fl::awake(setFreqDispB, (void *)vfoB.freq);
-		}
+	unsigned long int freq;
+	freq = selrig->get_vfoA();
+	if (freq != vfoA.freq) {
+		vfoA.freq = freq;
+		Fl::awake(setFreqDispA, (void *)vfoA.freq);
+		vfo = &vfoA;
 	}
-
-	if (progStatus.poll_mode) {
-		int nu_mode;
-		nu_mode = selrig->get_modeA();
-		if (nu_mode != vfoA.imode) {
-			vfoA.imode = vfo->imode = nu_mode;
-			selrig->set_bwA(vfo->iBW = selrig->adjust_bandwidth(nu_mode));
-			Fl::awake(setModeControl);
-			Fl::awake(updateBandwidthControl);
-		}
-		nu_mode = selrig->get_modeB();
-		if (nu_mode != vfoB.imode) {
-			vfoB.imode = nu_mode;
-		}
+	freq = selrig->get_vfoB();
+	if (freq != vfoB.freq) {
+		vfoB.freq = freq;
+		Fl::awake(setFreqDispB, (void *)vfoB.freq);
 	}
-
-	if (progStatus.poll_bandwidth) {
-		int nu_BW;
-		nu_BW = selrig->get_bwA();
-		if (nu_BW != vfoA.iBW) {
-			vfoA.iBW = vfo->iBW = nu_BW;
-			Fl::awake(setBWControl);
-		}
-		nu_BW = selrig->get_bwB();
-		if (nu_BW != vfoB.iBW) {
-			vfoB.iBW = nu_BW;
-		}
-	}
-
 }
 
+void read_KX3_mode()
+{
+	int nu_mode;
+	nu_mode = selrig->get_modeA();
+	if (nu_mode != vfoA.imode) {
+		vfoA.imode = vfo->imode = nu_mode;
+		selrig->set_bwA(vfo->iBW = selrig->adjust_bandwidth(nu_mode));
+		Fl::awake(setModeControl);
+		Fl::awake(updateBandwidthControl);
+	}
+	nu_mode = selrig->get_modeB();
+	if (nu_mode != vfoB.imode) {
+		vfoB.imode = nu_mode;
+	}
+}
+
+void read_KX3_bw()
+{
+	int nu_BW;
+	nu_BW = selrig->get_bwA();
+	if (nu_BW != vfoA.iBW) {
+		vfoA.iBW = vfo->iBW = nu_BW;
+		Fl::awake(setBWControl);
+	}
+	nu_BW = selrig->get_bwB();
+	if (nu_BW != vfoB.iBW) {
+		vfoB.iBW = nu_BW;
+	}
+}
+
+
 void KX3_set_split(int val)
 {
 	guard_lock serial_lock(&mutex_serial);
@@ -102,7 +100,7 @@ void KX3_set_split(int val)
 
 extern char *print(XCVR_STATE data);
 
-void KX3_A2B()
+void cb_KX3_A2B()
 {
 	guard_lock serial_lock(&mutex_serial);
 	vfoB = vfoA;
@@ -117,24 +115,31 @@ void cb_KX3_swapAB()
 {
 	guard_lock serial_lock(&mutex_serial);
 
-	XCVR_STATE temp = vfoA;
-	vfoA = vfoB;
-	vfoB = temp;
+	XCVR_STATE nuB = vfoA, nuA = vfoB;
+
+	selrig->set_vfoB(nuB.freq);
+	selrig->set_bwB(nuB.iBW);
+	selrig->set_modeB(nuB.imode);
+
+	selrig->set_vfoA(nuA.freq);
+	selrig->set_bwA(nuA.iBW);
+	selrig->set_modeA(nuA.imode);
+
+	vfoA = nuA;
+	vfoB = nuB;
 	vfo = &vfoA;
 
-	selrig->set_vfoB(vfoB.freq);
-	selrig->set_bwB(vfoB.iBW);
-	selrig->set_modeB(vfoB.imode);
-
-	selrig->set_vfoA(vfoA.freq);
-	selrig->set_bwA(vfoA.iBW);
-	selrig->set_modeA(vfoA.imode);
-
+	FreqDispA->value(vfoA.freq);
 	opBW->index(vfoA.iBW);
 	opMODE->index(vfoA.imode);
-	FreqDispA->value(vfoA.freq);
 
 	FreqDispB->value(vfoB.freq);
 
 	Fl::focus(FreqDispA);
 }
+
+void cb_KX3_IFsh()
+{
+	guard_lock serial_lock(&mutex_serial);
+	selrig->set_if_shift(9999);
+}
