@@ -32,6 +32,8 @@
 #include "ui.h"
 #include "cwioUI.h"
 #include "cwio.h"
+#include "fsk.h"
+#include "fskioUI.h"
 
 Fl_Light_Button *btnPOWER = (Fl_Light_Button *)0;
 
@@ -47,9 +49,6 @@ Hspinner *spnrOUTER = (Hspinner *)0;
 Hspinner *spnrNOTCH = (Hspinner *)0;
 Hspinner *spnrMICGAIN = (Hspinner *)0;
 
-static Fl_Double_Window *meter_scale_dialog = (Fl_Double_Window *)0;
-static Fl_Double_Window *meter_filters = (Fl_Double_Window *)0;
-
 Fl_Group* grp_menu = (Fl_Group *)0;
 
 Fl_Menu_Bar *small_menu=(Fl_Menu_Bar *)0;
@@ -58,7 +57,9 @@ Fl_Menu_Bar *wide_menu=(Fl_Menu_Bar *)0;
 Fl_Menu_Item *mnuExit = (Fl_Menu_Item *)0;
 Fl_Menu_Item *mnuConfig = (Fl_Menu_Item *)0;
 Fl_Menu_Item *mnuTooltips = (Fl_Menu_Item *)0;
+Fl_Menu_Item *mnuVoltmeter = (Fl_Menu_Item *)0;
 Fl_Menu_Item *mnuSchema = (Fl_Menu_Item *)0;
+Fl_Menu_Item *mnuEmbedTabs = (Fl_Menu_Item *)0;
 Fl_Menu_Item *mnuColorConfig = (Fl_Menu_Item *)0;
 Fl_Menu_Item *mnu_meter_filtering = (Fl_Menu_Item *)0;
 Fl_Menu_Item *mnuConfigXcvr = (Fl_Menu_Item *)0;
@@ -227,12 +228,19 @@ Fl_Wheel_Value_Slider *sldr_nb_level = (Fl_Wheel_Value_Slider *)0;
 Hspinner *spnr_bpf_center = (Hspinner *)0;
 
 Fl_Button *btnALC_SWR = (Fl_Button *)0;
-Fl_SigBar *sldrRcvSignal=(Fl_SigBar *)0;
-Fl_SigBar *sldrALC=(Fl_SigBar *)0;
-Fl_SigBar *sldrSWR=(Fl_SigBar *)0;
-Fl_SigBar *sldrFwdPwr=(Fl_SigBar *)0;
+
+Fl_SigBar *sldrRcvSignal = (Fl_SigBar *)0;
+Fl_SigBar *sldrALC = (Fl_SigBar *)0;
+Fl_SigBar *sldrSWR = (Fl_SigBar *)0;
+
+Fl_SigBar *sldrFwdPwr = (Fl_SigBar *)0;
 Fl_Button *scalePower = (Fl_Button *)0;
-Fl_Box *meter_fill_box=(Fl_Box *)0;
+
+Fl_SigBar *sldrVoltage = (Fl_SigBar *)0;
+Fl_Box    *scaleVoltage = (Fl_Box *)0;
+
+Fl_Box    *meter_fill_box=(Fl_Box *)0;
+
 cFreqControl *FreqDispA=(cFreqControl *)0;
 cFreqControl *FreqDispB=(cFreqControl *)0;
 Fl_Group *grp_row0a = (Fl_Group *)0;
@@ -370,6 +378,8 @@ Fl_Group *grpInitializing = (Fl_Group *)0;
 
 Fl_Progress *progress=(Fl_Progress *)0;
 
+Fl_Group *g_extras = (Fl_Group *)0;
+
 #define RIGHT_OF(widget) (widget->x() + widget->w())
 
 #include "ui_bitmaps.cxx"
@@ -396,15 +406,52 @@ static void cb_mnuTooltips(Fl_Menu_*, void*) {
 	progStatus.tooltips = ! progStatus.tooltips;
 }
 
+static void cb_mnuVoltmeter(Fl_Menu_*, void*) {
+	progStatus.display_voltmeter = !progStatus.display_voltmeter;
+	updateVmeter(NULL);
+}
+
 static void cb_mnuSchema(Fl_Menu_*, void*) {
+	int state = progStatus.show_tabs;
+	if (progStatus.embed_tabs && progStatus.show_tabs)
+		show_controls();
+	if (!progStatus.embed_tabs && tabs_dialog->visible())
+		tabs_dialog->hide();
 	progStatus.schema = !progStatus.schema;
 	adjust_control_positions();
+	if (state != progStatus.show_tabs)
+		show_controls();
+}
+
+static void cb_mnu_embed_tabs(Fl_Menu_*, void*) {
+
+	if (tabs_dialog && !progStatus.embed_tabs && tabs_dialog->visible()) {
+		tabs_dialog->hide();
+		show_controls();
+		progStatus.embed_tabs = true;
+		show_controls();
+	} else if (tabs_dialog && !progStatus.embed_tabs && !tabs_dialog->visible()) {
+		progStatus.embed_tabs = true;
+	} else if (progStatus.embed_tabs && progStatus.show_tabs) {
+		show_controls(); // close controls
+		progStatus.embed_tabs = false;
+		show_controls();
+	} else if (progStatus.embed_tabs && !progStatus.show_tabs) {
+		progStatus.embed_tabs = false;
+	}
+		
 }
 
 static void cb_mnuColorConfig(Fl_Menu_*, void*) {
 	setDisplayColors();
 }
 
+static void cb_mnu_show_meters(Fl_Menu_ *, void *) {
+	if (meters_dialog)
+		meters_dialog = win_meters();
+	meters_dialog->show();
+}
+
 static void cb_mnu_meter_filtering(Fl_Menu_*, void*) {
 	if (!meter_filters)
 		meter_filters = MetersDialog();
@@ -455,7 +502,11 @@ static void cb_mnuCMEDIA(Fl_Menu_*, void*) {
 	open_cmedia_tab();
 }
 
-static void cb_keyer(Fl_Menu_*, void*) {
+static void cb_mnuTMATE2(Fl_Menu_*, void*) {
+	open_tmate2_tab();
+}
+
+static void cb_CWkeyer(Fl_Menu_*, void*) {
 	if (cwio_keyer_dialog == 0)
 		cwio_keyer_dialog = cwio_window();
 	for (int n = 0; n < 12; n++) {
@@ -465,6 +516,16 @@ static void cb_keyer(Fl_Menu_*, void*) {
 	cwio_keyer_dialog->show();
 }
 
+static void cb_FSKkeyer(Fl_Menu_*, void*) {
+	if (FSK_keyer_dialog == 0)
+		FSK_keyer_dialog = fskio_window();
+	for (int n = 0; n < 12; n++) {
+		FSK_btn_msg[n]->label(progStatus.FSK_labels[n].c_str());
+		FSK_btn_msg[n]->redraw_label();
+	}
+	FSK_keyer_dialog->show();
+}
+
 //static void cb_mnuXMLRPC(Fl_Menu_*, void*) {
 //	open_xmlrpc_tab();
 //}
@@ -506,6 +567,10 @@ static void cb_scalePower(Fl_Button*, void*) {
 		select_power_meter_scales();
 }
 
+static void cb_mnu_power_meter_scale(Fl_Menu_ *, void *) {
+	select_power_meter_scales();
+}
+
 extern bool useB;
 
 static void cb_btnA(Fl_Light_Button*, void*) {
