@@ -32,6 +32,7 @@ Fl_Menu_Item menu_small_menu[] = {
  {_("PTT-Generic"), 0, (Fl_Callback*)cb_mnuPTT, 0, 0, FL_NORMAL_LABEL, 0, 14, 0},
  {_("PTT-GPIO"), 0, (Fl_Callback*)cb_mnuGPIO, 0, 0, FL_NORMAL_LABEL, 0, 14, 0},
  {_("AUX"), 0, (Fl_Callback*)cb_mnuAUX, 0, 0, FL_NORMAL_LABEL, 0, 14, 0},
+ {_("TMATE-2"), 0, (Fl_Callback*)cb_mnuTMATE2, 0, 0, FL_NORMAL_LABEL, 0, 14, 0},
  {_("Server"), 0, (Fl_Callback*)cb_mnuSERVER, 0, 0, FL_NORMAL_LABEL, 0, 14, 0},
  {_("Polling"), 0, (Fl_Callback*)cb_Polling, 0, 128, FL_NORMAL_LABEL, 0, 14, 0},
  {_("Commands"), 0, (Fl_Callback*)cb_mnuCommands, 0, 0, FL_NORMAL_LABEL, 0, 14, 0},
@@ -40,9 +41,13 @@ Fl_Menu_Item menu_small_menu[] = {
  {_("Trace"), 0, (Fl_Callback*)cb_mnuTrace, 0, 0, FL_NORMAL_LABEL, 0, 14, 0},
  {0,0,0,0,0,0,0,0,0},
  {_("UI"), 0, 0, 0, 64, FL_NORMAL_LABEL, 0, 14, 0},
+ {_("Meters dialog"), 0, (Fl_Callback*)cb_mnu_show_meters, 0, 128, FL_NORMAL_LABEL, 0, 14, 0},
  {_("Meter filtering"), 0,  (Fl_Callback*)cb_mnu_meter_filtering, 0, 128, FL_NORMAL_LABEL, 0, 14, 0},
+ {_("Power meter scale"), 0, (Fl_Callback*)cb_mnu_power_meter_scale, 0, 128, FL_NORMAL_LABEL, 0, 14, 0},
  {_("Small sliders"), 0,  (Fl_Callback*)cb_mnuSchema, 0, 130, FL_NORMAL_LABEL, 0, 14, 0},
+ {_("Embed tabs"), 0, (Fl_Callback*)cb_mnu_embed_tabs, 0, 130, FL_NORMAL_LABEL, 0, 14, 0},
  {_("Tooltips"), 0,  (Fl_Callback*)cb_mnuTooltips, 0, 130, FL_NORMAL_LABEL, 0, 14, 0},
+ {_("Voltmeter"), 0, (Fl_Callback*)cb_mnuVoltmeter, 0, 130, FL_NORMAL_LABEL, 0, 14, 0},
  {_("User Interface"), 0,  (Fl_Callback*)cb_mnuColorConfig, 0, 0, FL_NORMAL_LABEL, 0, 14, 0},
  {0,0,0,0,0,0,0,0,0},
  {0,0,0,0,0,0,0,0,0},
@@ -50,7 +55,10 @@ Fl_Menu_Item menu_small_menu[] = {
  {_("Save"), 0,  (Fl_Callback*)cb_save_me, 0, 0, FL_NORMAL_LABEL, 0, 14, 0},
  {_("Manage"), 0,  (Fl_Callback*)cb_Memory, 0, 0, FL_NORMAL_LABEL, 0, 14, 0},
  {0,0,0,0,0,0,0,0,0},
- {_("&Keyer"), 0, (Fl_Callback*)cb_keyer, 0, 0, FL_NORMAL_LABEL, 0, 14, 0},
+ {_("&Keyer"), 0, 0, 0, 64, FL_NORMAL_LABEL, 0, 14, 0},
+ {_("&CW Keyer"), 0, (Fl_Callback*)cb_CWkeyer, 0, 0, FL_NORMAL_LABEL, 0, 14, 0},
+ {_("&FSK Keyer"), 0, (Fl_Callback*)cb_FSKkeyer, 0, 0, FL_NORMAL_LABEL, 0, 14, 0},
+ {0,0,0,0,0,0,0,0,0},
  {_("&Help"), 0,  0, 0, 64, FL_NORMAL_LABEL, 0, 14, 0},
  {_("On Line Help"), 0,  (Fl_Callback*)cb_mnuOnLineHelp, 0, 0, FL_NORMAL_LABEL, 0, 14, 0},
  {_("&About"), 0,  (Fl_Callback*)cb_mnuAbout, 0, 128, FL_NORMAL_LABEL, 0, 14, 0},
@@ -595,6 +603,28 @@ CTRL  click: FreqB -> FreqA\
 			scalePower->image(image_P100);
 			scalePower->callback((Fl_Callback*)cb_scalePower);
 
+			sldrVoltage = new Fl_SigBar(5, 92, 200, 6);
+			sldrVoltage->box(FL_FLAT_BOX);
+			sldrVoltage->color(FL_BACKGROUND_COLOR);
+			sldrVoltage->selection_color(FL_BACKGROUND_COLOR);
+			sldrVoltage->labeltype(FL_NORMAL_LABEL);
+			sldrVoltage->labelfont(0);
+			sldrVoltage->labelsize(12);
+			sldrVoltage->labelcolor(FL_FOREGROUND_COLOR);
+			sldrVoltage->align(Fl_Align(FL_ALIGN_CENTER));
+			sldrVoltage->when(FL_WHEN_CHANGED);
+			sldrVoltage->hide();
+			sldrVoltage->minimum(0);
+			sldrVoltage->maximum(100);
+
+			scaleVoltage = new Fl_Box(3, 99, 206, 20);
+			scaleVoltage->box(FL_FLAT_BOX);
+			scaleVoltage->image(image_voltmeter);
+			scaleVoltage->tooltip(_("DC power"));
+
+			sldrVoltage->hide();
+			scaleVoltage->hide();
+
 			meter_fill_box = new Fl_Box(207, 63, 0, 57);
 			meter_fill_box->box(FL_FLAT_BOX);
 			meter_fill_box->color((Fl_Color)246);
@@ -1048,7 +1078,7 @@ Fl_Double_Window *tabs_window()
 	tabs550->end();
 
 	tabsGeneric = new Fl_Tabs(0, 0, small_mainW, gph);
-		tabsGeneric->selection_color(FL_LIGHT1);
+//		tabsGeneric->selection_color(FL_LIGHT1);
 
 		tab_yaesu_bands = new Fl_Group(0, 24, small_mainW, gph - 24, _("Band"));
 			btn_yaesu_select_1 = new Fl_Button(4, 40, 60, 18, _("1.8"));
@@ -1668,7 +1698,7 @@ Fl_Double_Window *tabs_window()
 //			kxpa_enabled->value(progStatus.kxpa);
 //		kx3_extras->end();
 
-		genericUser_1 = new Fl_Group(0, 24, small_mainW, gph - 24, _("Cmds A"));
+		genericUser_1 = new Fl_Group(0, 24, small_mainW, gph - 24, _("A"));
 			btnUser1 = new Fl_Button(5, genericUser_1->y() + 12, 100, 20, "USER 1");
 			btnUser1->callback((Fl_Callback*)cb_btnUser, (void*)1);
 
@@ -1750,22 +1780,12 @@ Fl_Double_Window *tabs_window()
 		genericUser_3->end();
 
 		tab7610 = new Fl_Group(0, 24, small_mainW, gph - 24, _("IC7610"));
-			ic7610att = new Fl_ComboBox(5, tab7610->y() + 10, 70, 20, "Att level");
-			ic7610att->add("OFF|3db|6db|9db|12db|15db|18db|21db|24db|27db|30db|33db|36db|39db|42db|45db|");
-			ic7610att->align(FL_ALIGN_RIGHT);
-			ic7610att->index(progStatus.index_ic7610att);
-			ic7610att->readonly();
-			ic7610att->callback((Fl_Callback *)cb_ic7610_att);
 
-			ic7610dual_watch = new Fl_Light_Button(150, tab7610->y() + 10, 120, 20, "Dual Watch");
-			ic7610dual_watch->value(progStatus.dual_watch);
-			ic7610dual_watch->callback((Fl_Callback *)cb_dual_watch);
-
-			ic7610digi_sel_on_off = new Fl_Light_Button(5, tab7610->y() + 35, 70, 20, "Digi-Sel");
+			ic7610digi_sel_on_off = new Fl_Light_Button(5, tab7610->y() + 10, 70, 22, "Digi-Sel");
 			ic7610digi_sel_on_off->value(progStatus.digi_sel_on_off);
 			ic7610digi_sel_on_off->callback((Fl_Callback *)cb_digi_sel_on_off);
 
-			ic7610_digi_sel_val = new Fl_Wheel_Value_Slider(80, tab7610->y() + 35, small_mainW - 85, 20, "");
+			ic7610_digi_sel_val = new Fl_Wheel_Value_Slider(80, tab7610->y() + 10, small_mainW - 85, 22, "");
 			ic7610_digi_sel_val->tooltip(_("Digi-Sel value"));
 			ic7610_digi_sel_val->type(5);
 			ic7610_digi_sel_val->box(FL_THIN_DOWN_BOX);
@@ -1783,6 +1803,20 @@ Fl_Double_Window *tabs_window()
 			ic7610_digi_sel_val->when(FL_WHEN_CHANGED);
 			ic7610_digi_sel_val->value(progStatus.digi_sel_val);
 
+			ic7610att = new Fl_ComboBox(5, tab7610->y() + 40, 80, 22, "Att level");
+			ic7610att->add("OFF|3db|6db|9db|12db|15db|18db|21db|24db|27db|30db|33db|36db|39db|42db|45db");
+			ic7610att->box(FL_NO_BOX);
+			ic7610att->color(FL_BACKGROUND2_COLOR);
+			ic7610att->selection_color(FL_BACKGROUND_COLOR);
+			ic7610att->align(FL_ALIGN_RIGHT);
+			ic7610att->index(progStatus.index_ic7610att);
+			ic7610att->readonly();
+			ic7610att->callback((Fl_Callback *)cb_ic7610_att);
+
+			ic7610dual_watch = new Fl_Light_Button(150, tab7610->y() + 40, 120, 22, "Dual Watch");
+			ic7610dual_watch->value(progStatus.dual_watch);
+			ic7610dual_watch->callback((Fl_Callback *)cb_dual_watch);
+
 		tab7610->end();
 
 		genericAux = new Fl_Group(0, 24, small_mainW, gph - 24, _("Aux"));
@@ -1811,6 +1845,13 @@ Fl_Double_Window *tabs_window()
 	w->end();
 	w->resizable(grpTABS);
 	w->size_range (small_mainW, gph, 0, gph);
+
+	Fl_Color clr = fl_rgb_color( progStatus.tab_red, progStatus.tab_green, progStatus.tab_blue);
+	tabsGeneric->selection_color(clr);
+	tabsGeneric->redraw();
+	tabs550->selection_color(clr);
+	tabs550->redraw();
+
 	return w;
 }
 
@@ -1830,12 +1871,24 @@ Fl_Double_Window* Small_rig_window() {
 			mnuTooltips = mnu;
 		}
 
+		mnu = getMenuItem(_("Voltmeter"), menu_small_menu);
+		if (mnu) {
+			progStatus.display_voltmeter ? mnu->set() : mnu->clear();
+			mnuVoltmeter = mnu;
+		}
+
 		mnu = getMenuItem(_("Small sliders"), menu_small_menu);
 		if (mnu) {
 			progStatus.schema ? mnu->set() : mnu->clear();
 			mnuSchema = mnu;
 		}
 
+		mnu = getMenuItem(_("Embed tabs"), menu_small_menu);
+		if (mnu) {
+			progStatus.embed_tabs ? mnu->set() : mnu->clear();
+			mnuEmbedTabs = mnu;
+		}
+
 		Fl_Group *mnu_box = new Fl_Group(small_mainW-64, 0, 64, small_menuH);
 		mnu_box->box(FL_UP_BOX);
 
