@@ -41,6 +41,7 @@ Fl_Menu_Item touch_menu[] = {
  {_("PTT-Generic"), 0, (Fl_Callback*)cb_mnuPTT, 0, 0, FL_NORMAL_LABEL, 0, 14, 0},
  {_("PTT-GPIO"), 0, (Fl_Callback*)cb_mnuGPIO, 0, 0, FL_NORMAL_LABEL, 0, 14, 0},
  {_("AUX"), 0, (Fl_Callback*)cb_mnuAUX, 0, 0, FL_NORMAL_LABEL, 0, 14, 0},
+ {_("TMATE-2"), 0, (Fl_Callback*)cb_mnuTMATE2, 0, 0, FL_NORMAL_LABEL, 0, 14, 0},
  {_("Server"), 0, (Fl_Callback*)cb_mnuSERVER, 0, 0, FL_NORMAL_LABEL, 0, 14, 0},
  {_("Polling"), 0, (Fl_Callback*)cb_Polling, 0, 128, FL_NORMAL_LABEL, 0, 14, 0},
  {_("Commands"), 0, (Fl_Callback*)cb_mnuCommands, 0, 0, FL_NORMAL_LABEL, 0, 14, 0},
@@ -49,8 +50,11 @@ Fl_Menu_Item touch_menu[] = {
  {_("Trace"), 0, (Fl_Callback*)cb_mnuTrace, 0, 0, FL_NORMAL_LABEL, 0, 14, 0},
  {0,0,0,0,0,0,0,0,0},
  {_("UI"), 0, 0, 0, 64, FL_NORMAL_LABEL, 0, 14, 0},
+ {_("Meters dialog"), 0, (Fl_Callback*)cb_mnu_show_meters, 0, 128, FL_NORMAL_LABEL, 0, 14, 0},
  {_("Meter filtering"), 0,  (Fl_Callback*)cb_mnu_meter_filtering, 0, 128, FL_NORMAL_LABEL, 0, 14, 0},
+ {_("Power meter scale"), 0, (Fl_Callback*)cb_mnu_power_meter_scale, 0, 128, FL_NORMAL_LABEL, 0, 14, 0},
  {_("Tooltips"), 0,  (Fl_Callback*)cb_mnuTooltips, 0, 130, FL_NORMAL_LABEL, 0, 14, 0},
+ {_("Voltmeter"), 0, (Fl_Callback*)cb_mnuVoltmeter, 0, 130, FL_NORMAL_LABEL, 0, 14, 0},
  {_("User Interface"), 0,  (Fl_Callback*)cb_mnuColorConfig, 0, 0, FL_NORMAL_LABEL, 0, 14, 0},
  {0,0,0,0,0,0,0,0,0},
  {0,0,0,0,0,0,0,0,0},
@@ -58,7 +62,10 @@ Fl_Menu_Item touch_menu[] = {
  {_("Save"), 0,  (Fl_Callback*)cb_save_me, 0, 0, FL_NORMAL_LABEL, 0, 14, 0},
  {_("Manage"), 0,  (Fl_Callback*)cb_Memory, 0, 0, FL_NORMAL_LABEL, 0, 14, 0},
  {0,0,0,0,0,0,0,0,0},
- {_("&Keyer"), 0, (Fl_Callback*)cb_keyer, 0, 0, FL_NORMAL_LABEL, 0, 14, 0},
+ {_("&Keyer"), 0, 0, 0, 64, FL_NORMAL_LABEL, 0, 14, 0},
+ {_("&CW Keyer"), 0, (Fl_Callback*)cb_CWkeyer, 0, 0, FL_NORMAL_LABEL, 0, 14, 0},
+ {_("&FSK Keyer"), 0, (Fl_Callback*)cb_FSKkeyer, 0, 0, FL_NORMAL_LABEL, 0, 14, 0},
+ {0,0,0,0,0,0,0,0,0},
  {_("&Help"), 0,  0, 0, 64, FL_NORMAL_LABEL, 0, 14, 0},
  {_("On Line Help"), 0,  (Fl_Callback*)cb_mnuOnLineHelp, 0, 0, FL_NORMAL_LABEL, 0, 14, 0},
  {_("&About"), 0,  (Fl_Callback*)cb_mnuAbout, 0, 128, FL_NORMAL_LABEL, 0, 14, 0},
@@ -246,6 +253,28 @@ Fl_Group *touch_main_group(int X, int Y, int W, int H)
 		scalePower->image(image_P100);
 		scalePower->callback((Fl_Callback*)cb_scalePower);
 
+		sldrVoltage = new Fl_SigBar(xpos+2, ypos+29, 200, 6);
+		sldrVoltage->box(FL_FLAT_BOX);
+		sldrVoltage->color(FL_BACKGROUND_COLOR);
+		sldrVoltage->selection_color(FL_BACKGROUND_COLOR);
+		sldrVoltage->labeltype(FL_NORMAL_LABEL);
+		sldrVoltage->labelfont(0);
+		sldrVoltage->labelsize(12);
+		sldrVoltage->labelcolor(FL_FOREGROUND_COLOR);
+		sldrVoltage->align(Fl_Align(FL_ALIGN_CENTER));
+		sldrVoltage->when(FL_WHEN_CHANGED);
+		sldrVoltage->hide();
+		sldrVoltage->minimum(0);
+		sldrVoltage->maximum(100);
+
+		scaleVoltage = new Fl_Box(xpos, ypos+36, 206, 20);
+		scaleVoltage->box(FL_FLAT_BOX);
+		scaleVoltage->image(image_voltmeter);
+		scaleVoltage->tooltip(_("DC power"));
+
+		sldrVoltage->hide();
+		scaleVoltage->hide();
+
 		meter_fill_box = new Fl_Box(xpos+210, ypos+4, 0, 57);
 		meter_fill_box->box(FL_FLAT_BOX);
 		meter_fill_box->color((Fl_Color)246);
@@ -1632,23 +1661,24 @@ CTRL  click: FreqB -> FreqA\
 
 			genericUser_3->end();
 
+			by += 10;
 			tab7610 = new Fl_Group(xpos, ypos+tabh, W, tabb, _("IC7610"));
-				ic7610att = new Fl_ComboBox(5, by, 120, 50, "Att level");
+				ic7610att = new Fl_ComboBox(5, by, 120, 30, "Att level");
 				ic7610att->add("OFF|3db|6db|9db|12db|15db|18db|21db|24db|27db|30db|33db|36db|39db|42db|45db|");
 				ic7610att->align(FL_ALIGN_RIGHT);
 				ic7610att->index(progStatus.index_ic7610att);
 				ic7610att->readonly();
 				ic7610att->callback((Fl_Callback *)cb_ic7610_att);
 
-				ic7610dual_watch = new Fl_Light_Button(210, by, 100, 50, "Dual Watch");
+				ic7610dual_watch = new Fl_Light_Button(210, by, 100, 30, "Dual Watch");
 				ic7610dual_watch->value(progStatus.dual_watch);
 				ic7610dual_watch->callback((Fl_Callback *)cb_dual_watch);
 
-				ic7610digi_sel_on_off = new Fl_Light_Button(320, by, 100, 50, "Digi-Sel");
+				ic7610digi_sel_on_off = new Fl_Light_Button(320, by, 100, 30, "Digi-Sel");
 				ic7610digi_sel_on_off->value(progStatus.digi_sel_on_off);
 				ic7610digi_sel_on_off->callback((Fl_Callback *)cb_digi_sel_on_off);
 
-				ic7610_digi_sel_val = new Fl_Wheel_Value_Slider(430, by, W - 440, 50, "");
+				ic7610_digi_sel_val = new Fl_Wheel_Value_Slider(430, by, W - 440, 30, "");
 				ic7610_digi_sel_val->tooltip(_("Digi-Sel value"));
 				ic7610_digi_sel_val->type(5);
 				ic7610_digi_sel_val->box(FL_THIN_DOWN_BOX);
@@ -2101,6 +2131,12 @@ Fl_Double_Window* touch_rig_window() {
 			mnuTooltips = mnu;
 		}
 
+		mnu = getMenuItem(_("Voltmeter"), touch_menu);
+		if (mnu) {
+			progStatus.display_voltmeter ? mnu->set() : mnu->clear();
+			mnuVoltmeter = mnu;
+		}
+
 		touch_menubar->menu(touch_menu);
 
 		Fl_Group *mnu_box = new Fl_Group(mainW-64, 0, 64, 28);
