@@ -21,6 +21,8 @@
 Fl_Group *gwide = (Fl_Group *)0;
 Fl_Group *grp_row1b1b = (Fl_Group *)0;
 
+Fl_Group *tabs = (Fl_Group *)0;
+
 Fl_Menu_Item menu_wide_menu[] = {
  {_("&File"), 0,  0, 0, 64, FL_NORMAL_LABEL, 0, 14, 0},
  {_("E&xit"), 0,  (Fl_Callback*)cb_mnuExit, 0, 0, FL_NORMAL_LABEL, 0, 14, 0},
@@ -33,6 +35,7 @@ Fl_Menu_Item menu_wide_menu[] = {
  {_("PTT-Generic"), 0, (Fl_Callback*)cb_mnuPTT, 0, 0, FL_NORMAL_LABEL, 0, 14, 0},
  {_("PTT-GPIO"), 0, (Fl_Callback*)cb_mnuGPIO, 0, 0, FL_NORMAL_LABEL, 0, 14, 0},
  {_("AUX"), 0, (Fl_Callback*)cb_mnuAUX, 0, 0, FL_NORMAL_LABEL, 0, 14, 0},
+ {_("TMATE-2"), 0, (Fl_Callback*)cb_mnuTMATE2, 0, 0, FL_NORMAL_LABEL, 0, 14, 0},
  {_("Server"), 0, (Fl_Callback*)cb_mnuSERVER, 0, 0, FL_NORMAL_LABEL, 0, 14, 0},
  {_("Polling"), 0, (Fl_Callback*)cb_Polling, 0, 128, FL_NORMAL_LABEL, 0, 14, 0},
  {_("Commands"), 0, (Fl_Callback*)cb_mnuCommands, 0, 0, FL_NORMAL_LABEL, 0, 14, 0},
@@ -41,8 +44,12 @@ Fl_Menu_Item menu_wide_menu[] = {
  {_("Trace"), 0, (Fl_Callback*)cb_mnuTrace, 0, 0, FL_NORMAL_LABEL, 0, 14, 0},
  {0,0,0,0,0,0,0,0,0},
  {_("UI"), 0, 0, 0, 64, FL_NORMAL_LABEL, 0, 14, 0},
+ {_("Meters dialog"), 0, (Fl_Callback*)cb_mnu_show_meters, 0, 128, FL_NORMAL_LABEL, 0, 14, 0},
  {_("Meter filtering"), 0,  (Fl_Callback*)cb_mnu_meter_filtering, 0, 128, FL_NORMAL_LABEL, 0, 14, 0},
+ {_("Power meter scale"), 0, (Fl_Callback*)cb_mnu_power_meter_scale, 0, 128, FL_NORMAL_LABEL, 0, 14, 0},
+ {_("Embed tabs"), 0, (Fl_Callback*)cb_mnu_embed_tabs, 0, 130, FL_NORMAL_LABEL, 0, 14, 0},
  {_("Tooltips"), 0,  (Fl_Callback*)cb_mnuTooltips, 0, 130, FL_NORMAL_LABEL, 0, 14, 0},
+ {_("Voltmeter"), 0, (Fl_Callback*)cb_mnuVoltmeter, 0, 130, FL_NORMAL_LABEL, 0, 14, 0},
  {_("User Interface"), 0,  (Fl_Callback*)cb_mnuColorConfig, 0, 0, FL_NORMAL_LABEL, 0, 14, 0},
  {0,0,0,0,0,0,0,0,0},
  {0,0,0,0,0,0,0,0,0},
@@ -50,7 +57,10 @@ Fl_Menu_Item menu_wide_menu[] = {
  {_("Save"), 0,  (Fl_Callback*)cb_save_me, 0, 0, FL_NORMAL_LABEL, 0, 14, 0},
  {_("Manage"), 0,  (Fl_Callback*)cb_Memory, 0, 0, FL_NORMAL_LABEL, 0, 14, 0},
  {0,0,0,0,0,0,0,0,0},
- {_("&Keyer"), 0, (Fl_Callback*)cb_keyer, 0, 0, FL_NORMAL_LABEL, 0, 14, 0},
+ {_("&Keyer"), 0, 0, 0, 64, FL_NORMAL_LABEL, 0, 14, 0},
+ {_("&CW Keyer"), 0, (Fl_Callback*)cb_CWkeyer, 0, 0, FL_NORMAL_LABEL, 0, 14, 0},
+ {_("&FSK Keyer"), 0, (Fl_Callback*)cb_FSKkeyer, 0, 0, FL_NORMAL_LABEL, 0, 14, 0},
+ {0,0,0,0,0,0,0,0,0},
  {_("&Help"), 0,  0, 0, 64, FL_NORMAL_LABEL, 0, 14, 0},
  {_("On Line Help"), 0,  (Fl_Callback*)cb_mnuOnLineHelp, 0, 0, FL_NORMAL_LABEL, 0, 14, 0},
  {_("&About"), 0,  (Fl_Callback*)cb_mnuAbout, 0, 128, FL_NORMAL_LABEL, 0, 14, 0},
@@ -62,7 +72,7 @@ Fl_Menu_Item menu_wide_menu[] = {
 
 Fl_Group *wide_main_group(int X, int Y, int W, int H)
 {
-	Fl_Group *g = new Fl_Group(X, Y, WIDE_MAINW, WIDE_MAINH);
+	Fl_Group *g = new Fl_Group(X, Y, W, H);
 	g->box(FL_FLAT_BOX);
 
 	int xpos = X + 2;
@@ -165,6 +175,28 @@ Fl_Group *wide_main_group(int X, int Y, int W, int H)
 			scalePower->image(image_P100);
 			scalePower->callback((Fl_Callback*)cb_scalePower);
 
+			sldrVoltage = new Fl_SigBar(xpos+2, ypos+29, 200, 6);
+			sldrVoltage->box(FL_FLAT_BOX);
+			sldrVoltage->color(FL_BACKGROUND_COLOR);
+			sldrVoltage->selection_color(FL_BACKGROUND_COLOR);
+			sldrVoltage->labeltype(FL_NORMAL_LABEL);
+			sldrVoltage->labelfont(0);
+			sldrVoltage->labelsize(12);
+			sldrVoltage->labelcolor(FL_FOREGROUND_COLOR);
+			sldrVoltage->align(Fl_Align(FL_ALIGN_CENTER));
+			sldrVoltage->when(FL_WHEN_CHANGED);
+			sldrVoltage->hide();
+			sldrVoltage->minimum(0);
+			sldrVoltage->maximum(100);
+
+			scaleVoltage = new Fl_Box(xpos+1, ypos+36, 206, 20);
+			scaleVoltage->box(FL_FLAT_BOX);
+			scaleVoltage->image(image_voltmeter);
+			scaleVoltage->tooltip(_("DC power"));
+
+			sldrVoltage->hide();
+			scaleVoltage->hide();
+
 			meter_fill_box = new Fl_Box(xpos+207, ypos, 0, 60);
 			meter_fill_box->box(FL_FLAT_BOX);
 			meter_fill_box->color((Fl_Color)246);
@@ -843,10 +875,11 @@ CTRL  click: FreqB -> FreqA\
 
 Fl_Double_Window* Wide_rig_window() {
 	int mainW = WIDE_MAINW;
+	int menuH = WIDE_MENUH;
 	int mainH = WIDE_MAINH;
-	int menuH = 22;
+	int tabsH = WIDE_TABSH;
 
-	Fl_Double_Window* w = new Fl_Double_Window(mainW, mainH, _("Flrig"));
+	Fl_Double_Window* w = new Fl_Double_Window(mainW, menuH + mainH + tabsH, _("Flrig"));
 	w->align(Fl_Align(FL_ALIGN_CLIP|FL_ALIGN_INSIDE));
 
 	grp_menu = new Fl_Group(0, 0, mainW, menuH);
@@ -861,6 +894,18 @@ Fl_Double_Window* Wide_rig_window() {
 			mnuTooltips = mnu;
 		}
 
+		mnu = getMenuItem(_("Voltmeter"), menu_wide_menu);
+		if (mnu) {
+			progStatus.display_voltmeter ? mnu->set() : mnu->clear();
+			mnuVoltmeter = mnu;
+		}
+
+		mnu = getMenuItem(_("Embed tabs"), menu_wide_menu);
+		if (mnu) {
+			progStatus.embed_tabs ? mnu->set() : mnu->clear();
+			mnuEmbedTabs = mnu;
+		}
+
 		Fl_Group *mnu_box = new Fl_Group(mainW - 64, 0, 64, menuH);
 		mnu_box->box(FL_UP_BOX);
 
@@ -884,10 +929,15 @@ Fl_Double_Window* Wide_rig_window() {
 
 	grp_menu->end();
 
-	main_group = wide_main_group(0, menuH, mainW, mainH - menuH);
+	main_group = wide_main_group(0, menuH, mainW, mainH);
+	main_group->end();
 	main_group->hide();
 
-	grpInitializing = new Fl_Group(0, 0, mainW, mainH, "");
+	tabs = new Fl_Group(0, menuH + mainH, mainW, tabsH);
+	tabs->box(FL_FLAT_BOX);
+	tabs->end();
+
+	grpInitializing = new Fl_Group(0, menuH, mainW, mainH + tabsH, "");
 
 		grpInitializing->box(FL_FLAT_BOX);
 		grpInitializing->color(FL_LIGHT2);
@@ -906,11 +956,7 @@ Fl_Double_Window* Wide_rig_window() {
 
 	grpInitializing->show();
 
-	w->resizable(main_group);
-
-	w->size(WIDE_MAINW, WIDE_MAINH);
-
-	w->size_range(WIDE_MAINW, WIDE_MAINH, 0, WIDE_MAINH);
+	w->resizable(tabs);
 
 	w->end();
 
