@@ -33,6 +33,8 @@
 #include "images/P200.xbm"
 #include "images/P200log.xbm"
 
+#include "images/volts.xbm"
+
 #include "images/S60.xbm"
 #include "images/SWR.xbm"
 #include "images/alc.xbm"
@@ -44,6 +46,8 @@ Fl_Bitmap image_p100(P100_bits, P100_width, P100_height);
 Fl_Bitmap image_p200(P200_bits, P200_width, P200_height);
 Fl_Bitmap image_p200log(P200log_bits, P200log_width, P200log_height);
 
+Fl_Bitmap image_voltmeter(volts_bits, volts_width, volts_height);
+
 Fl_Bitmap image_smeter(S60_bits, S60_width, S60_height);
 Fl_Bitmap image_swr(SWR_bits, SWR_width, SWR_height);
 Fl_Bitmap image_alc(alc_bits, alc_width, alc_height);
