@@ -20,7 +20,16 @@
 // aunsigned long int with this program.  If not, see <http://www.gnu.org/licenses/>.
 // ----------------------------------------------------------------------------
 
-void read_KX3();
-void KX3_set_split(int val);
-void KX3_A2B();
-void cb_KX3_swapAB();
+#ifndef KX3_UI_H
+#define KX3_UI_H
+
+extern void read_KX3_vfo();
+extern void read_KX3_mode();
+extern void read_KX3_bw();
+
+extern void KX3_set_split(int val);
+extern void cb_KX3_A2B();
+extern void cb_KX3_swapAB();
+extern void cb_KX3_IFsh();
+
+#endif
