@@ -72,7 +72,7 @@ enum TS2000MODES { LSB, USB, CW, FM, AM, FSK, CWR, FSKR, DIGI };
 //	void select_swr();
 //	void select_alc();
 	int  get_power_out();
-	int  get_power_control();
+	double get_power_control();
 //	void set_volume_control(int val);
 //	int  get_volume_control();
 	void set_power_control(double val);
