@@ -68,7 +68,7 @@ enum TS590MODES { LSB, USB, CW, FM, AM, FSK, CWR, FSKR, LSBD, USBD, FMD };
 	int  get_swr();
 	int  get_alc();
 	int  get_power_out();
-	int  get_power_control();
+	double get_power_control();
 
 //	void set_volume_control(int val);
 //	int  get_volume_control();
