@@ -70,6 +70,7 @@ extern Fl_Double_Window* Wide_rig_window();
 extern Fl_Double_Window* Small_rig_window();
 extern Fl_Double_Window* touch_rig_window();
 extern Fl_Double_Window* tabs_window();
+extern Fl_Double_Window* win_meters();
 
 extern void select_power_meter_scales();
 
@@ -87,6 +88,9 @@ extern Fl_SigBar *sldrFwdPwr;
 extern Fl_Button *scalePower;
 extern Fl_Box *meter_fill_box;
 
+extern Fl_SigBar *sldrVoltage;
+extern Fl_Box *scaleVoltage;
+
 extern cFreqControl *FreqDispA;
 extern cFreqControl *FreqDispB;
 extern Fl_Group *grp_row0a;
@@ -385,7 +389,9 @@ extern Fl_Menu_Item *mnuConfig;
 extern Fl_Menu_Item *mnuRestoreData;
 extern Fl_Menu_Item *mnuKeepData;
 extern Fl_Menu_Item *mnuTooltips;
+extern Fl_Menu_Item *mnuVoltmeter;
 extern Fl_Menu_Item *mnuSchema;
+extern Fl_Menu_Item *mnuEmbedTabs;
 extern Fl_Menu_Item *mnuColorConfig;
 extern Fl_Menu_Item *mnu_meter_filtering;
 extern Fl_Menu_Item *mnuConfigXcvr;
@@ -413,6 +419,8 @@ extern Fl_SigBar *sldrSWRcolor;
 extern Fl_Box *scaleSWRcolor;
 extern Fl_SigBar *sldrPWRcolor;
 extern Fl_Box *scalePWRcolor;
+extern Fl_SigBar *sldrVoltcolor;
+extern Fl_Box *scaleVoltcolor;
 extern Fl_Button *btMeterColor;
 extern Fl_Button *btnSWRColor;
 extern Fl_Button *btnPwrColor;
@@ -433,6 +441,8 @@ extern Fl_Return_Button *btnOkDisplayDialog;
 extern Fl_Light_Button *btn_lighted;
 extern Fl_Button *btn_lighted_default;
 
+extern Fl_Button *btn_tab_color;
+
 extern Fl_Button *btnAddFreq;
 extern Fl_Button *btnPickFreq;
 extern Fl_Button *btnDelFreq;
@@ -442,8 +452,6 @@ extern Fl_Browser2 *FreqSelect;
 
 extern Fl_Input *inAlphaTag;
 
-extern Fl_Tabs *tabsConfig;
-extern Fl_Group *tabPrimary;
 extern Fl_ComboBox *selectRig;
 
 extern Fl_Group *tabCommands;
@@ -610,4 +618,10 @@ extern Fl_ComboBox *inp_cmedia_GPIO_line;
 extern Fl_Button *btn_init_cmedia_PTT;
 extern Fl_Button *btn_test_cmedia;
 
+extern Fl_Group *tabTMATE2;
+extern Fl_ComboBox *cbo_tmate2_freq_step;
+extern Fl_ComboBox *cbo_tmate2_dev;
+
+extern Fl_Group *tabs;
+
 #endif
