@@ -81,6 +81,10 @@ struct status {
 	string	cmedia_gpio_line;
 	bool	cmedia_ptt;
 
+	string	tmate2_device;
+	string	tmate2_freq_step;
+	bool	tmate2_connected;
+
 	bool	disable_CW_ptt;
 
 	int		CIV;
@@ -141,6 +145,11 @@ struct status {
 	int		squelch;
 
 	int		schema;
+	int		embed_tabs;
+	int		show_tabs;
+	bool    first_use;
+	std::string visible_tab;
+
 	bool	hrd_buttons;
 	int		sliders_button;
 
@@ -401,6 +410,11 @@ struct status {
 	int		peakGreen;
 	int		peakBlue;
 
+	int		voltRed;
+	int		voltGreen;
+	int		voltBlue;
+	int		display_voltmeter;
+
 	int		fg_sys_red;
 	int		fg_sys_green;
 	int		fg_sys_blue;
@@ -425,6 +439,10 @@ struct status {
 	int		lighted_btn_green;
 	int		lighted_btn_blue;
 
+	int		tab_red;
+	int		tab_green;
+	int		tab_blue;
+
 	Fl_Font	fontnbr;
 
 	bool	tooltips;
@@ -509,6 +527,17 @@ struct status {
 	string	HM;
 	string	VE;
 
+// FSK_ parameters
+	int		FSK_KEYLINE;
+	int		FSK_SHARED;
+	int		FSK_PTT;
+	int		FSK_CONNECTED;
+	int		FSK_INVERTED;
+	int		FSK_STOPBITS;
+	string	FSK_PORT;
+	string	FSK_msgs[12];
+	string	FSK_labels[12];
+
 	void saveLastState();
 	void loadLastState();
 	bool loadXcvrState(string);
