@@ -247,6 +247,7 @@ extern void open_ptt_tab();
 extern void open_gpio_tab();
 extern void open_aux_tab();
 extern void open_server_tab();
+extern void open_tmate2_tab();
 
 extern void cb_close_TT550_setup();
 extern void cbUseRepeatButtons(bool on);
@@ -286,6 +287,7 @@ extern void cbPwrMeterColor();
 extern void cbSWRMeterColor();
 extern void cbPeakMeterColor();
 extern void cbBacklightColor();
+extern void cbVoltMeterColor();
 
 extern void cb_sys_defaults();
 extern void cb_sys_foreground();
@@ -303,6 +305,9 @@ extern void cb_change_hrd_button();
 extern void cb_change_sliders_button();
 extern void set_sliders_when();
 
+extern void cb_tab_defaults();
+extern void cb_tab_colors();
+
 // ic7610 functions
 
 extern void digi_sel_on_off();
@@ -333,6 +338,7 @@ extern void updateSmeter(void *d = 0);
 extern void updateFwdPwr(void *d = 0);
 extern void updateALC(void *d = 0);
 extern void updateSWR(void *d = 0);
+extern void updateVmeter(void *d = 0);
 extern void updateSquelch(void *d = 0);
 extern void updateRFgain(void *d = 0);
 extern void zeroXmtMeters(void *d = 0);
@@ -380,4 +386,16 @@ extern void update_progress(int);
 
 extern bool xcvr_online;
 
+extern Fl_Box *mtr_SMETER;
+extern Fl_Box *mtr_PWR;
+extern Fl_Box *mtr_SWR;
+extern Fl_Box *mtr_ALC;
+extern Fl_Box *mtr_VOLTS;
+
+extern Fl_SigBar *sigbar_SMETER;
+extern Fl_SigBar *sigbar_PWR;
+extern Fl_SigBar *sigbar_SWR;
+extern Fl_SigBar *sigbar_ALC;
+extern Fl_SigBar *sigbar_VOLTS;
+
 #endif
