@@ -75,7 +75,7 @@ public:
 	int  get_smeter();
 	int  get_swr();
 	int  get_power_out();
-	int  get_power_control();
+	double get_power_control();
 	void set_volume_control(int val);
 	void set_power_control(double val);
 	void get_pc_min_max_step(double &min, double &max, double &step) {
