@@ -437,7 +437,7 @@ void RIG_K3::set_power_control(double val)
 	sett("");
 }
 
-int RIG_K3::get_power_control()
+double RIG_K3::get_power_control()
 {
 	cmd = "PC;";
 	get_trace(1, "get power control");
@@ -452,6 +452,22 @@ int RIG_K3::get_power_control()
 
 void RIG_K3::get_pc_min_max_step(double &min, double &max, double &step)
 {
+	cmd = "OM;"; // request options to get power level
+	get_trace(1, "get options/pc_pwr_level");
+	int ret = wait_char(';', 16, K3_WAIT_TIME, "Options", ASC);
+	gett("");
+
+	if (ret) {
+		if (replystr.find("P") == string::npos) {
+			minpwr = 0;
+			maxpwr = 12;
+			steppwr = 1;
+		} else {
+			minpwr = 0;
+			maxpwr = 106;
+			steppwr = 1;
+		}
+	}
    min = minpwr; max = maxpwr; step = steppwr;
 }
 
@@ -560,8 +576,10 @@ int RIG_K3::get_smeter()
 
 	int mtr = fm_decimal(replystr.substr(p+2), 4);
 
-	if (mtr <= 6) mtr = (int) (50.0 * mtr / 6.0);
-	else mtr = (int)(50 + (mtr - 6.0) * 50.0 / 9.0);
+// use extended format conversion
+	if (mtr <= 9) mtr = (int) (50.0 * mtr / 9.0);
+	else mtr = (int)(50 + (mtr - 9.0) * 50.0 / 12.0);
+
 	return mtr;
 }
 
