@@ -24,6 +24,8 @@
 
 const char KX3name_[] = "KX3";
 
+enum {KX3_LSB, KX3_USB, KX3_CW, KX3_FM, KX3_AM, KX3_DATA, KX3_CWR, KX3_DATAR};
+
 const char *KX3modes_[] =
 	{ "LSB", "USB", "CW", "FM", "AM", "DATA", "CW-R", "DATA-R", NULL};
 const char modenbr[] =
@@ -142,8 +144,8 @@ static void init_trace()
 	progStatus.xmltrace    =
 	progStatus.trace       = false;
 
-//	progStatus.gettrace   = true;
-//	progStatus.settrace   = true;
+	progStatus.gettrace   = true;
+	progStatus.settrace   = true;
 //	progStatus.serialtrace = true;
 //	progStatus.rigtrace    = true;
 //	progStatus.xmltrace    = true;
@@ -152,6 +154,63 @@ static void init_trace()
 
 }
 
+/*
+ * OM (Option Module; GET)
+
+OM APF---TBXI0n;
+    |
+0123456789012345
+0.........1.....
+
+A = ATU
+P = external 100W PA
+F = roofing filter
+T = external 100W ATU
+B = internal NiMH battery charger/real-time clock
+X = KX3-2M or KX3-4M transverter module
+I = KXIO2 RTC I/O module
+0n = product identifer
+     1 - KX2
+     2 - KX3
+*/
+static struct KX3_OPTIONS {
+	bool ATU;
+	bool KXPA;
+	bool ROOF;
+	bool KXPA_ATU;
+	bool NICAD;
+	bool TXVRT;
+	bool RTC;
+	int  PROD;
+} options = { 
+	false,
+	false,
+	false,
+	false,
+	false,
+	false,
+	false,
+	0 };
+
+void RIG_KX3::get_options()
+{
+	cmd = "OM;";
+	get_trace(1, "get options");
+	int ret = wait_char(';', 16, KX3_WAIT_TIME, "get options", ASC);
+	gett("");
+	if (ret < 16)
+		return;
+
+	options.ATU  = (replystr[3] == 'A');
+	options.KXPA = (replystr[4] == 'P');
+	options.ROOF = (replystr[5] == 'F');
+	options.KXPA_ATU = (replystr[9] == 'T');
+	options.NICAD = (replystr[10] == 'B');
+	options.TXVRT = (replystr[11] == 'X');
+	options.RTC = (replystr[12] == 'I');
+	options.PROD = (replystr[14] - '0');
+}
+
 void RIG_KX3::initialize()
 {
 	init_trace();
@@ -182,6 +241,7 @@ void RIG_KX3::initialize()
 	sendCommand(cmd, 0, 50);
 	sett("");
 	showresp(INFO, ASC, "disable auto-info", cmd, replystr);
+
 }
 
 void RIG_KX3::shutdown()
@@ -196,7 +256,7 @@ void RIG_KX3::shutdown()
 bool RIG_KX3::check ()
 {
 	static char sztemp[50];
-isok=true;
+
 	if (isok) return true;
 
 // try reading vfoA
@@ -544,23 +604,30 @@ int RIG_KX3::next_attenuator()
 
 void RIG_KX3::get_pc_min_max_step(double &min, double &max, double &step)
 {
-	min = 0; max = 15; step = 1;
+	get_options();
+	if (options.KXPA) {
+		min = 0; max = 110; step = 1;
+	} else {
+		min = 0; max = 15; step = 1;
+	}
 }
 
-static std::string pwr = "000;001;002;003;004;005;006;007;008;009;010;011;012;013;014;015;";
-
 void RIG_KX3::set_power_control(double val)
 {
 	int ival = val;
-	cmd = "PC";
-	cmd.append(pwr.substr(ival * 4, 4));
+	cmd = "PC000;";
+	cmd[4] += ival % 10;
+	ival /= 10;
+	cmd[3] += ival % 10;
+	ival /= 10;
+	cmd[2] += ival % 10;
 	set_trace(1, "set power control");
 	sendCommand(cmd, 0, 50);
 	showresp(INFO, ASC, "set power ctrl", cmd, replystr);
 	sett("");
 }
 
-int RIG_KX3::get_power_control()
+double RIG_KX3::get_power_control()
 {
 	cmd = "PC;";
 
@@ -571,10 +638,11 @@ int RIG_KX3::get_power_control()
 	if (ret < 6) return progStatus.power_level;
 
 	size_t p = replystr.rfind("PC");
-	if (p == string::npos) return progStatus.power_level;
-	size_t val = pwr.find(replystr.substr(p+2, 4));
-	if (val != std::string::npos) val /= 4;
-	return val;
+	if (p == string::npos)
+		return progStatus.power_level;
+
+	replystr[p+5] = 0;
+	return atoi(&replystr[p+2]);
 }
 
 /*
@@ -600,12 +668,12 @@ int RIG_KX3::get_power_out()
 	size_t p = 0;
 	int mtr = 0;
 
-	if (progStatus.kxpa) {		// test for KXPA-100 on line
+	if (options.KXPA) {
 		cmd = "^OP;";
 		get_trace(1, "test KXPA");
 		ret = wait_char(';', 5, KX3_WAIT_TIME, "test KXPA", ASC);
 		gett("");
-		if (ret >= 4) {
+		if (ret >= 5) {
 			powerScale = 1;
 			if (replystr.find("^OP1;") != string::npos) {
 				cmd = "^PF;";
@@ -617,8 +685,7 @@ int RIG_KX3::get_power_out()
 					mtr = atoi(&replystr[p+3]);
 					if (mtr > 0) return mtr/10;
 				}
-			}
-			return 0;
+			} // in standby mode, fall through to read power out on KX3
 		}
 	}
 
@@ -634,7 +701,7 @@ int RIG_KX3::get_power_out()
 	if (p == string::npos) return 0;
 	replystr[p + 5] = 0;
 	mtr = atoi(&replystr[p + 2]); 
-// mtr is power is tenths
+// mtr is power in tenths
 	powerScale = 10;
 	return mtr;
 }
@@ -731,6 +798,53 @@ void RIG_KX3::set_PTT_control(int val)
 	ptt_ = val;
 }
 
+/*
+ * IF (Transceiver Information; GET only)
+ *   RSP format: IF[f]*****+yyyyrx*00tmvspbd1*;
+ *   where the fields are defined as follows:
+ *     [f]    Operating frequency, excluding any RIT/XIT offset
+ *            (11 digits; see FA command format)
+ *      *     represents a space (BLANK, or ASCII 0x20)
+ *      +     either "+" or "-" (sign of RIT/XIT offset)
+ *      yyyy  RIT/XIT offset in Hz (range is -9999 to +9999 Hz when
+ *            computer-controlled)
+ *      r     1 if RIT is on, 0 if off
+ *      x     1 if XIT is on, 0 if off
+ *      t     1 if the K3 is in transmit mode, 0 if receive
+ *      m     operating mode (see MD command)
+ *      v     receive-mode VFO selection, 0 for VFO A, 1 for VFO B
+ *      s     1 if scan is in progress, 0 otherwise
+ *      p     1 if the transceiver is in split mode, 0 otherwise
+ *      b     Basic RSP format: always 0;
+ *            K2 Extended RSP format (K22):
+ *            1 if present IF response is due to a band change; 0 otherwise
+ *      d     Basic RSP format: always 0;
+ *            K3 Extended RSP format (K31):
+ *      1     DATA sub-mode, if applicable
+ *              (0=DATA A, 1=AFSK A, 2= FSK D, 3=PSK D)
+ * The fixed-value fields (space, 0, and 1) are provided for syntactic
+ * compatibility with existing software.
+ *
+ * 01234567890123456789012345678901234567
+ * 0         1         2         3      7
+ * IF00014070000*****+yyyyrx*00tmvspbd1*;
+ *   |         |               |   |  |_____ [35] data submode 
+ *   |         |               |   |________ [32] split on = '1', off = '0'
+ *   |         |               |____________ [28] PTT state; 1 = TX, 0 = RX 
+ *   |---------|____________________________ [02...12] vfo a/b
+*/
+
+int RIG_KX3::get_PTT()
+{
+	cmd = "IF;";
+	get_trace(1, "get PTT");
+	int ret = wait_char(';', 38, KX3_WAIT_TIME, "get split", ASC);
+	gett("");
+	if (ret < 38) return ptt_;
+	size_t p = replystr.rfind("IF");
+	return ptt_ = (replystr[p+28] == '1');
+}
+
 // BG (Bargraph Read; GET only)
 // RSP format: BGnn; where <nn> is 00 (no bars) through 10 (bar 10) if the
 // bargraph is in DOT mode, and 12 (no bars) through 22 (all 10 bars) if
@@ -762,8 +876,9 @@ int RIG_KX3::get_smeter()
 	if (p == string::npos) return 0;
 
 	int mtr = fm_decimal(replystr.substr(p+2), 4);
-	if (mtr <= 6) mtr = (int) (50.0 * mtr / 6.0);
-	else mtr = (int)(50 + (mtr - 6.0) * 50.0 / 9.0);
+// use extended format conversion
+	if (mtr <= 9) mtr = (int) (50.0 * mtr / 9.0);
+	else mtr = (int)(50 + (mtr - 9.0) * 50.0 / 12.0);
 
 	return mtr;
 }
@@ -964,11 +1079,6 @@ bool RIG_KX3::get_if_shift(int &val)
 	return 1;
 }
 
-void RIG_KX3::get_if_min_max_step(int &min, int &max, int &step)
-{
-	min = if_shift_min; max = if_shift_max; step = if_shift_step;
-}
-
 void  RIG_KX3::get_if_mid()
 {
 	cmd = "IS 9999;";
@@ -989,8 +1099,69 @@ void  RIG_KX3::get_if_mid()
 	sscanf(&replystr[p + 3], "%d", &if_shift_mid);
 }
 
+// KX3_LSB, KX3_USB, KX3_CW, KX3_FM, KX3_AM, KX3_DATA, KX3_CWR, KX3_DATAR
+void RIG_KX3::get_if_min_max_step(int &min, int &max, int &step)
+{
+	int md = modeA;
+	if (inuse == onB) md = modeB;
+	switch (md) {
+		case KX3_CW: case KX3_CWR:
+			if_shift_min = 330;
+			if_shift_max = 770;
+			if_shift_step = 10;
+			break;
+		case KX3_LSB:
+		case KX3_USB:
+		case KX3_DATA:
+		case KX3_DATAR:
+			if_shift_min = 1280;
+			if_shift_max = 1700;
+			if_shift_step = 10;
+			break;
+		default:
+			if_shift_min = 1500;
+			if_shift_max = 1500;
+			if_shift_step = 10;
+			break;
+	}
+	min = if_shift_min;
+	max = if_shift_max;
+	step = if_shift_step;
+	get_if_mid();
+}
+
+// ^OP; return ^OPn;  5 characters
+//      ^OP1; signifies that KXPA100 is on-line and active
+// SW; return SWnnn;  6 characters
+// ^SW; return ^SWnnn;  7 characters (don't believe the programmer's guide!)
 int RIG_KX3::get_swr()
 {
+	if (options.KXPA) {
+		cmd = "^OP;";
+		get_trace(1, "test KXPA");
+		int ret = wait_char(';', 5, KX3_WAIT_TIME, "test KXPA", ASC);
+		gett("");
+		if (ret >= 5) {
+			powerScale = 1;
+			if (replystr.find("^OP1;") != string::npos) {
+				cmd = "^SW;";
+				get_trace(1, "get KXPA SWR");
+				ret = wait_char(';', 7, KX3_WAIT_TIME, "get KXPA SWR reading", ASC);
+				gett("");
+				if (ret >= 7) {
+					size_t p = replystr.rfind("^SW");
+					if (p != string::npos) {
+						replystr[p + 6] = 0;
+						int mtr = fm_decimal(replystr.substr(p+3), 3);
+						if (mtr <= 30) mtr = (int) (50.0 * (mtr - 10) / 20.0);
+						else mtr = (int)(50 + 50 * (mtr - 30) / 70);
+						return mtr;
+					}
+				}
+			} // in standby mode or not present, fall through to read SWR on KX3
+		}
+	}
+
 	cmd = "SW;";
 
 	get_trace(1, "get swr");
