@@ -30,6 +30,7 @@
 rigbase			rig_null;
 
 RIG_AOR5K		rig_AOR5K;
+RIG_FDMDUO		rig_FDMDUO;
 RIG_FT100D		rig_FT100D;
 RIG_FT450		rig_FT450;
 RIG_FT450D		rig_FT450D;
@@ -55,6 +56,7 @@ RIG_FT991A		rig_FT991A;
 RIG_FT1000		rig_FT1000;
 RIG_FT1000MP	rig_FT1000MP;
 RIG_FT2000		rig_FT2000;
+RIG_FTdx10		rig_FTdx10;
 RIG_FTdx101D	rig_FTdx101D;
 RIG_FTdx101MP	rig_FTdx101MP;
 RIG_FTdx1200	rig_FTdx1200;
@@ -121,101 +123,105 @@ RIG_XI5105		rig_XI5105;
 RIG_Xiegu_G90	rig_XIG90;
 RIG_PowerSDR	rig_PowerSDR;
 RIG_FLEX1500	rig_FLEX1500;
+RIG_TX500		rig_TX500;
 
 rigbase *rigs[] = {
 	&rig_null,		// 0
-	&rig_FT100D,	// 1
-	&rig_FT450,		// 2
-	&rig_FT450D,	// 3
-	&rig_FT736R,	// 4
-	&rig_FT747,		// 5
-	&rig_FT757GX2,	// 6
-	&rig_FT767,		// 7
-	&rig_FT817,		// 8
-	&rig_FT817BB,	// 9
-	&rig_FT818ND,	// 10
-	&rig_FT847,		// 11
-	&rig_FT857D,	// 12
-	&rig_FT890,		// 13
-	&rig_FT897D,	// 14
-	&rig_FT891,		// 15
-	&rig_FT900,		// 16
-	&rig_FT920,		// 17
-	&rig_FT950,		// 18
-	&rig_FT990,		// 19
-	&rig_FT990A,	// 20
-	&rig_FT991,		// 21
-	&rig_FT991A,	// 22
-	&rig_FT1000,	// 23
-	&rig_FT1000MP,	// 24
-	&rig_FT2000,	// 25
-	&rig_FTdx101D,	// 26
-	&rig_FTdx101MP,	// 27
-	&rig_FTdx1200,	// 28
-	&rig_FTdx3000,	// 29
-	&rig_FT5000,	// 30
-	&rig_FTdx9000,	// 31
-	&rig_IC703,		// 32
-	&rig_IC705,		// 33
-	&rig_IC706MKIIG,// 34
-	&rig_IC718,		// 35
-	&rig_IC728,		// 36
-	&rig_IC735,		// 37
-	&rig_IC746,		// 38
-	&rig_IC746PRO,	// 39
-	&rig_IC756,		// 40
-	&rig_IC756PRO,	// 41
-	&rig_IC756PRO2,	// 42
-	&rig_IC756PRO3,	// 43
-	&rig_IC7000,	// 44
-	&rig_IC7100,	// 45
-	&rig_IC7200,	// 46
-	&rig_IC7300,	// 47
-	&rig_IC7410,	// 48
-	&rig_IC7600,	// 49
-	&rig_IC7610,	// 50
-	&rig_IC7700,	// 51
-	&rig_IC7800,	// 52
-	&rig_IC7851,	// 53
-	&rig_IC9100,	// 54
-	&rig_IC9700,	// 55
-	&rig_IC910H,	// 56
-	&rig_ICF8101,	// 57
-	&rig_K2,		// 58
-	&rig_K3,		// 59
-	&rig_KX3,		// 60
-	&rig_PCR1000,	// 61
-	&rig_RAY152,	// 62
-	&rig_TMD710,	// 63
-	&rig_TS140,		// 64
-	&rig_TS440,		// 65
-	&rig_TS450S,	// 66
-	&rig_TS480HX,	// 67
-	&rig_TS480SAT,	// 68
-	&rig_TS570,		// 69
-	&rig_TS590S,	// 70
-	&rig_TS590SG,	// 71
-	&rig_TS790,		// 72
-	&rig_TS850,		// 73
-	&rig_TS870S,	// 74
-	&rig_TS890S,	// 75
-	&rig_TS940S,	// 76
-	&rig_TS950,		// 77
-	&rig_TS990,		// 78
-	&rig_TS2000,	// 79
-	&rig_TT516,		// 80
-	&rig_TT535,		// 81
-	&rig_TT538,		// 82
-	&rig_TT550,		// 83
-	&rig_TT563,		// 84
-	&rig_TT566,		// 85
-	&rig_TT588,		// 86
-	&rig_TT599,		// 87
-	&rig_AOR5K,		// 88
-	&rig_XI5105,	// 89
-	&rig_XIG90,		// 90
-	&rig_PowerSDR,	// 91
-	&rig_FLEX1500,	// 92
+	&rig_FDMDUO,	// 1
+	&rig_FT100D,	// 2
+	&rig_FT450,		// 3
+	&rig_FT450D,	// 4
+	&rig_FT736R,	// 5
+	&rig_FT747,		// 6
+	&rig_FT757GX2,	// 7
+	&rig_FT767,		// 8
+	&rig_FT817,		// 9
+	&rig_FT817BB,	// 10
+	&rig_FT818ND,	// 11
+	&rig_FT847,		// 12
+	&rig_FT857D,	// 13
+	&rig_FT890,		// 14
+	&rig_FT897D,	// 15
+	&rig_FT891,		// 16
+	&rig_FT900,		// 17
+	&rig_FT920,		// 18
+	&rig_FT950,		// 19
+	&rig_FT990,		// 20
+	&rig_FT990A,	// 21
+	&rig_FT991,		// 22
+	&rig_FT991A,	// 23
+	&rig_FT1000,	// 24
+	&rig_FT1000MP,	// 25
+	&rig_FT2000,	// 26
+	&rig_FTdx10,	// 27
+	&rig_FTdx101D,	// 28
+	&rig_FTdx101MP,	// 29
+	&rig_FTdx1200,	// 20
+	&rig_FTdx3000,	// 31
+	&rig_FT5000,	// 32
+	&rig_FTdx9000,	// 33
+	&rig_IC703,		// 34
+	&rig_IC705,		// 35
+	&rig_IC706MKIIG,// 36
+	&rig_IC718,		// 37
+	&rig_IC728,		// 38
+	&rig_IC735,		// 39
+	&rig_IC746,		// 40
+	&rig_IC746PRO,	// 41
+	&rig_IC756,		// 42
+	&rig_IC756PRO,	// 43
+	&rig_IC756PRO2,	// 44
+	&rig_IC756PRO3,	// 45
+	&rig_IC7000,	// 46
+	&rig_IC7100,	// 47
+	&rig_IC7200,	// 48
+	&rig_IC7300,	// 49
+	&rig_IC7410,	// 50
+	&rig_IC7600,	// 51
+	&rig_IC7610,	// 52
+	&rig_IC7700,	// 53
+	&rig_IC7800,	// 54
+	&rig_IC7851,	// 55
+	&rig_IC9100,	// 56
+	&rig_IC9700,	// 57
+	&rig_IC910H,	// 58
+	&rig_ICF8101,	// 59
+	&rig_K2,		// 60
+	&rig_K3,		// 61
+	&rig_KX3,		// 62
+	&rig_PCR1000,	// 63
+	&rig_RAY152,	// 64
+	&rig_TMD710,	// 65
+	&rig_TS140,		// 66
+	&rig_TS440,		// 67
+	&rig_TS450S,	// 68
+	&rig_TS480HX,	// 69
+	&rig_TS480SAT,	// 70
+	&rig_TS570,		// 71
+	&rig_TS590S,	// 72
+	&rig_TS590SG,	// 73
+	&rig_TS790,		// 74
+	&rig_TS850,		// 75
+	&rig_TS870S,	// 76
+	&rig_TS890S,	// 77
+	&rig_TS940S,	// 78
+	&rig_TS950,		// 79
+	&rig_TS990,		// 80
+	&rig_TS2000,	// 81
+	&rig_TT516,		// 82
+	&rig_TT535,		// 83
+	&rig_TT538,		// 84
+	&rig_TT550,		// 85
+	&rig_TT563,		// 86
+	&rig_TT566,		// 87
+	&rig_TT588,		// 88
+	&rig_TT599,		// 89
+	&rig_AOR5K,		// 90
+	&rig_XI5105,	// 91
+	&rig_XIG90,		// 92
+	&rig_PowerSDR,	// 93
+	&rig_FLEX1500,	// 94
+	&rig_TX500,		// 95
 
 	NULL
 };
