@@ -164,6 +164,7 @@ RIG_FT991A::RIG_FT991A() {
 	has_smeter =
 	has_alc_control =
 	has_swr_control =
+	has_voltmeter =
 	has_power_out =
 	has_power_control =
 	has_volume_control =
@@ -470,6 +471,28 @@ int RIG_FT991A::get_alc()
 	return (int)ceil(mtr / 2.56);
 }
 
+double RIG_FT991A::get_voltmeter()
+{
+	cmd = "RM8;";
+	string resp = "RM";
+
+	int mtr = 0;
+	double val = 0;
+
+	get_trace(1, "get_voltmeter()");
+	wait_char(';',7, FL991A_WAIT_TIME, "get vdd", ASC);
+	gett("get vdd");
+
+	size_t p = replystr.rfind(resp);
+	if (p != string::npos) {
+		mtr = atoi(&replystr[p+3]);
+		val = (7.0 * mtr / 98.0) + 0.14;
+		return val;
+	}
+
+	return -1;
+}
+
 int RIG_FT991A::get_power_out()
 {
 	cmd = rsp = "RM5";
