@@ -353,7 +353,7 @@ double RIG_FTdx1200::getVfoAdj()
 	return (double)(atoi(&replystr[p+5]));
 }
 
-void RIG_FTdx1200::get_vfoadj_min_max_step(int &min, int &max, int &step)
+void RIG_FTdx1200::get_vfoadj_min_max_step(double &min, double &max, double &step)
 {
 	min = -25;
 	max = 25;
@@ -517,7 +517,7 @@ int RIG_FTdx1200::get_power_out()
 }
 
 // Transceiver power level
-int RIG_FTdx1200::get_power_control()
+double RIG_FTdx1200::get_power_control()
 {
 	cmd = rsp = "PC";
 	cmd += ';';
@@ -1633,3 +1633,21 @@ bool RIG_FTdx1200::set_cw_APF()
 		return false;
 }
 */
+
+// ---------------------------------------------------------------------
+// set date and time
+// ---------------------------------------------------------------------
+// tm formated as HH:MM:SS
+// ---------------------------------------------------------------------
+void RIG_FTdx1200::sync_clock(char *tm)
+{
+	cmd.assign("DT1");
+	cmd += tm[0]; cmd += tm[1];
+	cmd += tm[3]; cmd += tm[4];
+	cmd += tm[6]; cmd += tm[7];
+	cmd += ';';
+	sendCommand(cmd);
+	showresp(WARN, ASC, "sync_time", cmd, replystr);
+	sett("sync_time");
+}
+
