@@ -52,6 +52,7 @@
 #include "rigpanel.h"
 #include "gettext.h"
 #include "cwioUI.h"
+#include "fskioUI.h"
 
 using namespace std;
 
@@ -77,6 +78,7 @@ void clear_combos()
 	selectAuxPort->add("NONE");
 	selectSepPTTPort->add("NONE");
 	select_cwioPORT->add("NONE");
+	select_fskioPORT->add("NONE");
 }
 
 void add_combos(char *port)
@@ -85,6 +87,7 @@ void add_combos(char *port)
 	selectAuxPort->add(port);
 	selectSepPTTPort->add(port);
 	select_cwioPORT->add(port);
+	select_fskioPORT->add(port);
 }
 
 void set_combo_value()
@@ -93,6 +96,7 @@ void set_combo_value()
 	selectAuxPort->value(progStatus.aux_serial_port.c_str());
 	selectSepPTTPort->value(progStatus.sep_serial_port.c_str());
 	select_cwioPORT->value(progStatus.cwioPORT.c_str());
+	select_fskioPORT->value(progStatus.FSK_PORT.c_str());
 }
 
 //======================================================================
@@ -489,6 +493,11 @@ void open_cmedia_tab()
 	select_tab(_("PTT-Cmedia"));
 }
 
+void open_tmate2_tab()
+{
+	select_tab(_("TMATE-2"));
+}
+
 void open_ptt_tab()
 {
 	select_tab(_("PTT-Generic"));
@@ -562,6 +571,7 @@ uchar smeterRed, smeterGreen, smeterBlue;
 uchar peakRed, peakGreen, peakBlue;
 uchar pwrRed, pwrGreen, pwrBlue;
 uchar swrRed, swrGreen, swrBlue;
+uchar voltRed, voltGreen, voltBlue;
 
 Fl_Color bgclr;
 Fl_Color fgclr;
@@ -584,6 +594,9 @@ static uchar btn_slider_red, btn_slider_green, btn_slider_blue;
 Fl_Color btn_lt_color;
 static uchar btn_lt_color_red, btn_lt_color_green, btn_lt_color_blue;
 
+Fl_Color tab_color;
+static uchar tab_red, tab_green, tab_blue;
+
 void cb_lighted_button()
 {
 	uchar r = btn_lt_color_red, g = btn_lt_color_green, b = btn_lt_color_blue;
@@ -761,13 +774,18 @@ void cbBacklightColor()
 		bg_red = r; bg_green = g; bg_blue = b;
 		bgclr = fl_rgb_color(r, g, b);
 		lblTest->color(bgclr);
+
 		sldrRcvSignalColor->color( fl_rgb_color (smeterRed, smeterGreen, smeterBlue), bgclr );
 		sldrPWRcolor->color(fl_rgb_color (pwrRed, pwrGreen, pwrBlue), bgclr);
 		sldrSWRcolor->color(fl_rgb_color (swrRed, swrGreen, swrBlue), bgclr);
+		sldrVoltcolor->color(fl_rgb_color (voltRed, voltGreen, voltBlue), bgclr);
+
 		scaleSmeterColor->color(bgclr);
 		scalePWRcolor->color(bgclr);
 		scaleSWRcolor->color(bgclr);
+		scaleVoltcolor->color(bgclr);
 		grpMeterColor->color(bgclr);
+
 		dlgDisplayConfig->redraw();
 	}
 }
@@ -779,9 +797,12 @@ void cbPrefForeground()
 		fg_red = r; fg_green = g; fg_blue = b;
 		fgclr = fl_rgb_color(r, g, b);
 		lblTest->labelcolor(fgclr);
+
 		scaleSmeterColor->labelcolor(fgclr);
 		scalePWRcolor->labelcolor(fgclr);
 		scaleSWRcolor->labelcolor(fgclr);
+		scaleVoltcolor->labelcolor(fgclr);
+
 		grpMeterColor->labelcolor(fgclr);
 		dlgDisplayConfig->redraw();
 	}
@@ -799,13 +820,16 @@ void default_meters()
 		scaleSmeterColor->color(bgclr);
 		scalePWRcolor->color(bgclr);
 		scaleSWRcolor->color(bgclr);
+		scaleVoltcolor->color(bgclr);
 		grpMeterColor->color(bgclr);
+
 	fg_red = 0; fg_green = 0; fg_blue = 0;
 	fgclr = (Fl_Color)0;
 		lblTest->labelcolor(fgclr);
 		scaleSmeterColor->labelcolor(fgclr);
 		scalePWRcolor->labelcolor(fgclr);
 		scaleSWRcolor->labelcolor(fgclr);
+		scaleVoltcolor->labelcolor(fgclr);
 		grpMeterColor->labelcolor(fgclr);
 	smeterRed = 0; smeterGreen = 180; smeterBlue = 0;
 		c = fl_rgb_color (smeterRed, smeterGreen, smeterBlue);
@@ -815,12 +839,18 @@ void default_meters()
 		sldrRcvSignalColor->PeakColor(c);
 		sldrPWRcolor->PeakColor(c);
 		sldrSWRcolor->PeakColor(c);
+		sldrVoltcolor->PeakColor(bgclr);
 	pwrRed = 180; pwrGreen = 0; pwrBlue = 0;
 		c = fl_rgb_color( pwrRed, pwrGreen, pwrBlue );
 		sldrPWRcolor->color(c, bgclr);
 	swrRed = 148; swrGreen = 0; swrBlue = 148;
 		c = fl_rgb_color(swrRed, swrGreen, swrBlue);
 		sldrSWRcolor->color(c, bgclr);
+	voltRed = 0; voltGreen = 0; voltBlue = 128;
+	voltRed = 0; voltGreen = 0; voltBlue = 255;
+		c = fl_rgb_color(voltRed, voltGreen, voltBlue);
+		sldrVoltcolor->color(c, bgclr);
+
 	dlgDisplayConfig->redraw();
 }
 
@@ -851,7 +881,7 @@ void cbPeakMeterColor()
 void cbPwrMeterColor()
 {
 	uchar r = pwrRed, g = pwrGreen, b = pwrBlue;
-	if (fl_color_chooser("Power color", r, g, b)) {
+	if (fl_color_chooser("Power meter color", r, g, b)) {
 		pwrRed = r; pwrGreen = g; pwrBlue = b;
 		sldrPWRcolor->color(
 			fl_rgb_color (r, g, b),
@@ -863,7 +893,7 @@ void cbPwrMeterColor()
 void cbSWRMeterColor()
 {
 	uchar r = swrRed, g = swrGreen, b = swrBlue;
-	if (fl_color_chooser("Power color", r, g, b)) {
+	if (fl_color_chooser("SWR meter color", r, g, b)) {
 		swrRed = r; swrGreen = g; swrBlue = b;
 		sldrSWRcolor->color(
 			fl_rgb_color (swrRed, swrGreen, swrBlue),
@@ -872,6 +902,68 @@ void cbSWRMeterColor()
 	}
 }
 
+void cbVoltMeterColor()
+{
+	uchar r = voltRed, g = voltGreen, b = voltBlue;
+	if (fl_color_chooser("Volt meter color", r, g, b)) {
+		voltRed = r; voltGreen = g; voltBlue = b;
+		sldrVoltcolor->color(
+			fl_rgb_color (voltRed, voltGreen, voltBlue),
+			bgclr );
+		dlgDisplayConfig->redraw();
+	}
+}
+
+void cb_tab_defaults()
+{
+	tab_red = 230;
+	tab_green = 230;
+	tab_blue = 230;
+
+	tab_color = fl_rgb_color( tab_red, tab_green, tab_blue);
+
+	btn_tab_color->color(tab_color);
+	btn_tab_color->redraw();
+
+	if (tabsGeneric) {
+		tabsGeneric->selection_color(tab_color);
+		tabsGeneric->redraw();
+	}
+	if (tabs550) {
+		tabs550->selection_color(tab_color);
+		tabs550->redraw();
+	}
+	if (tabCmds) {
+		tabCmds->selection_color(tab_color);
+		tabCmds->redraw();
+	}
+
+}
+
+void cb_tab_colors()
+{
+	uchar r = tab_red, g = tab_green, b = tab_blue;
+	if (fl_color_chooser("TAB color", r, g, b)) {
+		tab_red = r; tab_green = g; tab_blue = b;
+		tab_color = fl_rgb_color(r, g, b);
+		btn_tab_color->color(tab_color);
+		btn_tab_color->redraw();
+
+		if (tabsGeneric) {
+			tabsGeneric->selection_color(tab_color);
+			tabsGeneric->redraw();
+		}
+		if (tabs550) {
+			tabs550->selection_color(tab_color);
+			tabs550->redraw();
+		}
+		if (tabCmds) {
+			tabCmds->selection_color(tab_color);
+			tabCmds->redraw();
+		}
+	}
+}
+
 void setColors()
 {
 	progStatus.swrRed = swrRed;
@@ -890,6 +982,10 @@ void setColors()
 	progStatus.peakGreen = peakGreen;
 	progStatus.peakBlue = peakBlue;
 
+	progStatus.voltRed = voltRed;
+	progStatus.voltGreen = voltGreen;
+	progStatus.voltBlue = voltBlue;
+
 	progStatus.fg_red = fg_red;
 	progStatus.fg_green = fg_green;
 	progStatus.fg_blue = fg_blue;
@@ -926,6 +1022,10 @@ void setColors()
 	progStatus.lighted_btn_green = btn_lt_color_green;
 	progStatus.lighted_btn_blue = btn_lt_color_blue;
 
+	progStatus.tab_red = tab_red;
+	progStatus.tab_green = tab_green;
+	progStatus.tab_blue = tab_blue;
+
 	if (useB) {
 		FreqDispB->SetONOFFCOLOR( fl_rgb_color(fg_red, fg_green, fg_blue), bgclr);
 		FreqDispA->SetONOFFCOLOR(
@@ -944,23 +1044,43 @@ void setColors()
 
 	scaleSmeter->color(bgclr);
 	scaleSmeter->labelcolor(fgclr);
+	mtr_SMETER->color(bgclr);
+	mtr_SMETER->labelcolor(fgclr);
+
 
 	scalePower->color(bgclr);
 	scalePower->labelcolor(fgclr);
+	mtr_PWR->color(bgclr);
+	mtr_PWR->labelcolor(fgclr);
+
+	scaleVoltage->color(bgclr);
+	scaleVoltage->labelcolor(fgclr);
+	scaleVoltage->redraw();
+	mtr_VOLTS->color(bgclr);
+	mtr_VOLTS->labelcolor(fgclr);
 
 	btnALC_SWR->color(bgclr);
 	btnALC_SWR->labelcolor(fgclr);
 	btnALC_SWR->redraw();
+	mtr_SWR->color(bgclr);
+	mtr_SWR->labelcolor(fgclr);
 
 	sldrFwdPwr->color(fl_rgb_color (pwrRed, pwrGreen, pwrBlue), bgclr);
 	sldrFwdPwr->PeakColor(fl_rgb_color(peakRed, peakGreen, peakBlue));
 
+	sldrVoltage->color(fl_rgb_color (voltRed, voltGreen, voltBlue), bgclr);
+	sldrVoltage->PeakColor(bgclr);//fl_rgb_color (voltRed, voltGreen, voltBlue));
+	sldrVoltage->redraw();
+
 	sldrRcvSignal->color(fl_rgb_color (smeterRed, smeterGreen, smeterBlue), bgclr);
 	sldrRcvSignal->PeakColor(fl_rgb_color(peakRed, peakGreen, peakBlue));
 
 	sldrALC->color(fl_rgb_color (swrRed, swrGreen, swrBlue), bgclr);
 	sldrALC->PeakColor(fl_rgb_color(peakRed, peakGreen, peakBlue));
 
+	mtr_ALC->color(bgclr);
+	mtr_ALC->labelcolor(fgclr);
+
 	sldrSWR->color(fl_rgb_color (swrRed, swrGreen, swrBlue), bgclr);
 	sldrSWR->PeakColor(fl_rgb_color(peakRed, peakGreen, peakBlue));
 
@@ -1059,6 +1179,10 @@ void setDisplayColors()
 	peakGreen = progStatus.peakGreen;
 	peakBlue = progStatus.peakBlue;
 
+	voltRed = progStatus.voltRed;
+	voltGreen = progStatus.voltGreen;
+	voltBlue = progStatus.voltBlue;
+
 	fg_red = progStatus.fg_red;
 	fg_green = progStatus.fg_green;
 	fg_blue = progStatus.fg_blue;
@@ -1090,6 +1214,10 @@ void setDisplayColors()
 	btn_slider_green = progStatus.slider_btn_green;
 	btn_slider_blue = progStatus.slider_btn_blue;
 
+	tab_red = progStatus.tab_red;
+	tab_green = progStatus.tab_green;
+	tab_blue = progStatus.tab_blue;
+
 	sldrColors->color(fl_rgb_color(bg_slider_red, bg_slider_green, bg_slider_blue));
 	sldrColors->selection_color(fl_rgb_color(btn_slider_red, btn_slider_green, btn_slider_blue));
 
@@ -1106,6 +1234,8 @@ void setDisplayColors()
 	scalePWRcolor->labelcolor(fgclr);
 	scaleSWRcolor->color(bgclr);
 	scaleSWRcolor->labelcolor(fgclr);
+	scaleVoltcolor->color(bgclr);
+	scaleVoltcolor->labelcolor(fgclr);
 	grpMeterColor->color(bgclr);
 	grpMeterColor->labelcolor(fgclr);
 
@@ -1118,19 +1248,26 @@ void setDisplayColors()
 	sldrSWRcolor->color(
 		fl_rgb_color (swrRed, swrGreen, swrBlue),
 		bgclr );
+	sldrVoltcolor->color(
+		fl_rgb_color (voltRed, voltGreen, voltBlue),
+		bgclr );
 
 	sldrRcvSignalColor->minimum(0);
 	sldrRcvSignalColor->maximum(100);
-	sldrRcvSignalColor->value(25);
+	sldrRcvSignalColor->value(45);
 
 	sldrPWRcolor->minimum(0);
 	sldrPWRcolor->maximum(100);
-	sldrPWRcolor->value(25);
+	sldrPWRcolor->value(80);
 
 	sldrSWRcolor->minimum(0);
 	sldrSWRcolor->maximum(100);
 	sldrSWRcolor->value(25);
 
+	sldrVoltcolor->minimum(0);
+	sldrVoltcolor->maximum(100);
+	sldrVoltcolor->value(55);
+
 	btn_lt_color = fl_rgb_color( btn_lt_color_red, btn_lt_color_green, btn_lt_color_blue);
 	btn_slider = fl_rgb_color( btn_slider_red, btn_slider_green, btn_slider_blue);
 	bg_slider = fl_rgb_color(bg_slider_red, bg_slider_green, bg_slider_blue);
@@ -1161,7 +1298,7 @@ void openMemoryDialog()
 void show_controls()
 {
 	switch (progStatus.UIsize) {
-		case touch_ui : 
+		case touch_ui : {
 			if (selrig->name_ == rig_TT550.name_) {
 				tabs550->show();
 				tabsGeneric->hide();
@@ -1173,7 +1310,8 @@ void show_controls()
 			}
 			mainwindow->redraw();
 			break;
-		case wide_ui :
+		}
+		case wide_ui : {
 			if (selrig->name_ == rig_TT550.name_) {
 				tabsGeneric->hide();
 				tabs550->show();
@@ -1183,17 +1321,77 @@ void show_controls()
 				tabsGeneric->show();
 				tabsGeneric->redraw();
 			}
-			if (tabs_dialog->visible())
-				tabs_dialog->hide();
-			else {
-				tabs_dialog->resize(
-					mainwindow->x(), mainwindow->y() + mainwindow->decorated_h(),
-					mainwindow->w(), tabs_dialog->h());
-				tabs_dialog->show();
-				tabs_dialog->redraw();
+			Fl_Widget * vtab = (Fl_Widget *)0;
+			if (tabsGeneric) {
+				Fl_Widget * const *vtabs = tabsGeneric->array();
+				int ntabs = tabsGeneric->children();
+				for (int n = 0; n < ntabs; n++)
+					if (progStatus.visible_tab == vtabs[n]->label()) {
+						vtab = vtabs[n];
+						break;
+					}
+			}
+			if (progStatus.embed_tabs) { // embedded
+				int X = mainwindow->x(),
+					Y = mainwindow->y(),
+					W = mainwindow->w(),
+					H = mainwindow->h();
+				if ((progStatus.show_tabs && !progStatus.first_use) ||
+					(!progStatus.show_tabs && progStatus.first_use)) {
+
+					H = WIDE_MAINH + WIDE_MENUH;
+					mainwindow->resize( X, Y, W, H );
+					mainwindow->size_range(WIDE_MAINW, H, 0, H);
+
+					tabs->hide();
+					progStatus.show_tabs = false;
+					mainwindow->redraw();
+				} else { 
+					H = WIDE_MENUH + WIDE_MAINH + WIDE_TABSH;
+
+					mainwindow->resize( X, Y, W, H);
+					mainwindow->size_range(WIDE_MAINW, H, 0, H);
+
+					tabs->add(grpTABS);
+					grpTABS->resize(
+						tabs->x(), tabs->y(),
+						tabs->w(), tabs->h());
+					grpTABS->show();
+					tabs->show();
+					progStatus.show_tabs = true;
+
+					if (vtab != (Fl_Widget *)0) tabsGeneric->value(vtab);
+					mainwindow->redraw();
+				}
+			} else {
+				if ((progStatus.show_tabs && !progStatus.first_use) || (!progStatus.show_tabs && progStatus.first_use)) {
+					tabs_dialog->hide();
+					progStatus.show_tabs = false;
+				} else if ((!progStatus.show_tabs && !progStatus.first_use) || (progStatus.show_tabs && progStatus.first_use)) {
+					static int X, Y, W, H, dH;
+					X = mainwindow->x();
+					Y = mainwindow->y();
+					W = mainwindow->w();
+					H = WIDE_MAINH + WIDE_MENUH;
+
+					dH = mainwindow->decorated_h();
+					tabs_dialog->resize( X, Y + dH, W, tabs_dialog->h() );
+					grpTABS->resize(0, 0, W, tabs_dialog->h());
+					if (vtab != (Fl_Widget *)0) tabsGeneric->value(vtab);
+					tabs_dialog->add(grpTABS);
+					tabs_dialog->show();
+					tabs_dialog->redraw();
+					progStatus.show_tabs = true;
+
+					mainwindow->resize( X, Y, W, H);
+					mainwindow->size_range(WIDE_MAINW, H, 0, H);
+
+					mainwindow->redraw();
+				}
 			}
 			break;
-		case small_ui :
+		}
+		case small_ui : {
 			if (selrig->name_ == rig_TT550.name_) {
 				tabsGeneric->hide();
 				tabs550->show();
@@ -1203,18 +1401,78 @@ void show_controls()
 				tabsGeneric->show();
 				tabsGeneric->redraw();
 			}
-			if (tabs_dialog->visible())
-				tabs_dialog->hide();
-			else {
-				tabs_dialog->position(
-					mainwindow->x(), mainwindow->y() + mainwindow->decorated_h());
-				tabs_dialog->show();
-				tabs_dialog->redraw();
+			Fl_Widget * vtab = (Fl_Widget *)0;
+			if (tabsGeneric) {
+				Fl_Widget * const *vtabs = tabsGeneric->array();
+				int ntabs = tabsGeneric->children();
+				for (int n = 0; n < ntabs; n++)
+					if (progStatus.visible_tab == vtabs[n]->label()) {
+						vtab = vtabs[n];
+						break;
+					}
+			}
+			if (progStatus.embed_tabs) { // embedded
+				static int X = mainwindow->x(),
+						   Y = mainwindow->y(),
+						   W = mainwindow->w(),
+						   H = mainwindow->h();
+				if ((progStatus.show_tabs && !progStatus.first_use) || (!progStatus.show_tabs && progStatus.first_use)) {
+					tabs_dialog->add(grpTABS);
+					grpTABS->resize(tabs_dialog->x(), tabs_dialog->y(), tabs_dialog->w(), tabs_dialog->h());
+					mainwindow->resize(mainwindow->x(), mainwindow->y(), W, H);
+					progStatus.show_tabs = false;
+				} else if (!progStatus.show_tabs && !progStatus.first_use) {
+					X = mainwindow->x();
+					Y = mainwindow->y();
+					W = mainwindow->w();
+					H = mainwindow->h();
+					mainwindow->resize(X, Y, W, H + grpTABS->h());
+					grpTABS->resize(0, H, W, grpTABS->h());
+					mainwindow->add(grpTABS);
+					if (vtab != (Fl_Widget *)0) tabsGeneric->value(vtab);
+					grpTABS->show();
+					progStatus.show_tabs = true;
+
+				} else if (progStatus.show_tabs && progStatus.first_use) {
+					X = mainwindow->x();
+					Y = mainwindow->y();
+					W = mainwindow->w();
+					H = mainwindow->h();
+					mainwindow->resize(X, Y, W, H + grpTABS->h());
+					grpTABS->resize(0, H, W, grpTABS->h());
+					mainwindow->add(grpTABS);
+					if (vtab != (Fl_Widget *)0) tabsGeneric->value(vtab);
+
+					grpTABS->show();
+
+					progStatus.show_tabs = true;
+
+				}
+			} else {
+				if ((progStatus.show_tabs && !progStatus.first_use) || (!progStatus.show_tabs && progStatus.first_use)) {
+					tabs_dialog->hide();
+					progStatus.show_tabs = false;
+				} else if ((!progStatus.show_tabs && !progStatus.first_use) || (progStatus.show_tabs && progStatus.first_use)) {
+					static int X, Y, W, dH;
+					X = progStatus.mainX;
+					Y = progStatus.mainY;
+					W = progStatus.mainW;
+					dH = mainwindow->decorated_h();
+					tabs_dialog->resize( X, Y + dH, W, tabs_dialog->h() );
+					grpTABS->resize(0, 0, W, tabs_dialog->h());
+					if (vtab != (Fl_Widget *)0) tabsGeneric->value(vtab);
+					tabs_dialog->add(grpTABS);
+					tabs_dialog->show();
+					tabs_dialog->redraw();
+					progStatus.show_tabs = true;
+				}
 			}
 			break;
+		}
 		default :
 			break;
 	}
+	progStatus.first_use = false;
 }
 
 // a replica of the default color map used by Fltk
