@@ -93,6 +93,10 @@ status progStatus = {
 	"GPIO-3",	// string	cmedia_gpio_line
 	false,		// bool	cmedia_ptt
 
+	"NONE",		// string	tmate2_devide
+	"5000",		// string	tmate2_freq_step
+	false,		// bool		tmate2_connected
+
 	false,		// bool	disable_CW_ptt;
 
 	0,			// int	CIV;
@@ -153,6 +157,10 @@ status progStatus = {
 	10,			// int  squelch;
 
 	0,			// int  schema;
+	0,			// int	embed_tabs;
+	0,			// int	show_tabs;
+	true,       // bool first_use;			true only during program start
+	"",			// std::string visible_tab;
 	true,		// bool hrd_buttons
 	FL_WHEN_CHANGED,	// int sliders_button
 
@@ -190,10 +198,10 @@ status progStatus = {
 	0,			// int  split;
 	0,			// int  no_txqsy
 
-	5,			// int rx_avg;
-	5,			// int rx_peak;
-	5,			// int pwr_avg;
-	5,			// int pwr_peak;
+	1,			// int rx_avg;
+	4,			// int rx_peak;
+	1,			// int pwr_avg;
+	4,			// int pwr_peak;
 	4,			// int pwr_scale ==> Autoselect
 
 	1,			// bool sync_clock
@@ -409,6 +417,11 @@ status progStatus = {
 	0,			// int	peakGreen;
 	0,			// int	peakBlue;
 
+	0,			// int	voltRed;
+	0,			// int	voltGreen;
+	255,		// int	voltBlue;
+	0,			// int	display_voltmeter;
+
 	0,			// int	fg_sys_red;
 	0,			// int	fg_sys_green;
 	0,			// int	fg_sys_blue;
@@ -433,6 +446,10 @@ status progStatus = {
 	255,		// int		lighted_btn_green;
 	0,			// int		lighted_btn_blue;
 
+	230,		// int		tab_red;
+	230,		// int		tab_green;
+	230,		// int		tab_blue;
+
 	FL_COURIER,	// Fl_Font fontnbr;
 
 	false,		// bool	 tooltips;
@@ -499,7 +516,7 @@ status progStatus = {
 // cwio parameters
 	20,			// int    cwioWPM;
 	2,			// int    cwioKEYLINE; 1 == RTS, 2 == DTR
-	0,			// int    cwioSHARED; 0 = NONE, 1 = CAT, 2 = AUX, 3 = SEP
+	0,			// int    cwioSHARED; 0 = NONE, 1 = CAT, 2 = AUX, 3 = SEP, 4 = CWIO
 	0,			// int    cwioPTT; 1 - use PTT, 0 - use Brea-in
 	0,			// int    cwioCONNECTED; 1 - connected state; 0 - unconnected state
 	0,			// int    cwioINVERTED; 1 - DTR/RTS (-) keying; 
@@ -521,6 +538,20 @@ status progStatus = {
 	"{",		// string	HM;
 	"}",		// string	VE;
 
+// FSK_ parameters
+	1,			// int		FSK_KEYLINE; 1 == RTS, 2 == DTR
+	0,			// int		FSK_SHARED; 0 = NONE, 1 = CAT, 2 = AUX, 3 = SEP
+	0,			// int		FSK_PTT; 1 - use PTT, 0 - use Brea-in
+	0,			// int		FSK_CONNECTED; 1 - connected state; 0 - unconnected state
+	0,			// int		FSK_INVERTED; reverse keying; 
+	1,			// int		FSK_STOPBITS; 1 - 1.5; 0 - 2
+	"",			// string	FSK_PORT;
+
+	"","","","","","",
+	"","","","","","",					// string	FSK_msgs[12];
+	"m2","m2","m3","m4","m4","m6",
+	"m7","m8","m9","m10","m11","m12"	// string	FSK_labels[12];
+
 };
 
 void status::saveLastState()
@@ -541,12 +572,21 @@ void status::saveLastState()
 		memH = dlgMemoryDialog->h();
 	}
 
-	if (mX >= 0 && mX >= 0) {
+	if (mX >= 0 && mY >= 0) {
 		mainX = mX;
 		mainY = mY;
-		if (UIsize == touch_ui || UIsize == wide_ui) { mainW = mW; mainH = mH; }
+		if (UIsize == wide_ui) {
+			if (mW < WIDE_MAINW)
+				mW = WIDE_MAINW;
+			mH = WIDE_MAINH;
+		}
+		mainW = mW;
+		mainH = mH;
 	}
 
+	if (tabsGeneric)
+		visible_tab = (tabsGeneric->value())->label();
+
 	Fl_Preferences spref(RigHomeDir.c_str(), "w1hkj.com", xcvr_name.c_str());
 
 	spref.set("version", PACKAGE_VERSION);
@@ -604,6 +644,10 @@ void status::saveLastState()
 	spref.set("cmedia_gpio_line", cmedia_gpio_line.c_str());
 	spref.set("cmedia_ptt", cmedia_ptt);
 
+	spref.set("tmate2_device", tmate2_device.c_str());
+	spref.set("tmate2_freq_step", tmate2_freq_step.c_str());
+	spref.set("tmate2_connected", tmate2_connected);
+
 	spref.set("poll_smeter", poll_smeter);
 	spref.set("poll_frequency", poll_frequency);
 	spref.set("poll_mode", poll_mode);
@@ -689,6 +733,9 @@ void status::saveLastState()
 	spref.set("no_txqsy", no_txqsy);
 
 	spref.set("schema", schema);
+	spref.set("embed_tabs", embed_tabs);
+	spref.set("show_tabs", show_tabs);
+	spref.set("visible_tab", visible_tab.c_str());
 
 	spref.set("rx_avg", rx_avg);
 	spref.set("rx_peak", rx_peak);
@@ -947,6 +994,11 @@ void status::saveLastState()
 	spref.set("peak_green", peakGreen);
 	spref.set("peak_blue", peakBlue);
 
+	spref.set("volt_red", voltRed);
+	spref.set("volt_green", voltGreen);
+	spref.set("volt_blue", voltBlue);
+	spref.set("display_voltmeter", display_voltmeter);
+
 	spref.set("fg_sys_red", fg_sys_red);
 	spref.set("fg_sys_green", fg_sys_green);
 	spref.set("fg_sys_blue", fg_sys_blue);
@@ -971,6 +1023,10 @@ void status::saveLastState()
 	spref.set("lighted_btn_green", lighted_btn_green);
 	spref.set("lighted_btn_blue", lighted_btn_blue);
 
+	spref.set("tab_red", tab_red);
+	spref.set("tab_green", tab_green);
+	spref.set("tab_blue", tab_blue);
+
 	spref.set("fontnbr", fontnbr);
 
 	spref.set("tooltips", tooltips);
@@ -1080,13 +1136,13 @@ void status::saveLastState()
 	spref.set("cwioCONNECTED", cwioCONNECTED);
 	spref.set("cwioINVERTED", cwioINVERTED);
 	spref.set("cwioPORT", cwioPORT.c_str());
+
 	char setbuff[20];
 	for (int n = 0; n < 12; n++) {
 		snprintf(setbuff, sizeof(setbuff), "cwiolabel[%d]", n);
 		spref.set(setbuff, cwio_labels[n].c_str());
 		snprintf(setbuff, sizeof(setbuff), "cwiomessage[%d]", n);
 		spref.set(setbuff, cwio_msgs[n].c_str());
-	
 	}
 
 	spref.set("BT", BT.c_str());
@@ -1099,6 +1155,21 @@ void status::saveLastState()
 	spref.set("HM", HM.c_str());
 	spref.set("VE", VE.c_str());
 
+	spref.set("FSK_KEYLINE", FSK_KEYLINE);
+	spref.set("FSK_SHARED", FSK_SHARED);
+	spref.set("FSK_PTT", FSK_PTT);
+	spref.set("FSK_CONNECTED", FSK_CONNECTED);
+	spref.set("FSK_INVERTED", FSK_INVERTED);
+	spref.set("FSK_STOPBITS", FSK_STOPBITS);
+	spref.set("FSK_PORT", FSK_PORT.c_str());
+
+	for (int n = 0; n < 12; n++) {
+		snprintf(setbuff, sizeof(setbuff), "fskiolabel[%d]", n);
+		spref.set(setbuff, FSK_labels[n].c_str());
+		snprintf(setbuff, sizeof(setbuff), "fskiomessage[%d]", n);
+		spref.set(setbuff, FSK_msgs[n].c_str());
+	}
+
 }
 
 bool status::loadXcvrState(string xcvr)
@@ -1116,6 +1187,12 @@ bool status::loadXcvrState(string xcvr)
 		spref.get("mainh", mainH, mainH);
 		spref.get("uisize", UIsize, UIsize);
 
+		if (UIsize == wide_ui) {
+			if (mainW < WIDE_MAINW)
+				mainW = WIDE_MAINW;
+			mainH = WIDE_MAINH;
+		}
+
 		spref.get("memx", memX, memX);
 		spref.get("memy", memY, memY);
 		spref.get("memw", memW, memW);
@@ -1128,9 +1205,7 @@ bool status::loadXcvrState(string xcvr)
 			UIsize = current_ui_size;
 		}
 		current_ui_size = UIsize;
-		if (UIsize == wide_ui) {
-			mainW = progStatus.mainW;//WIDE_MAINW;
-		}
+
 		if (UIsize == small_ui) {
 			mainW = SMALL_MAINW;
 		}
@@ -1199,6 +1274,12 @@ bool status::loadXcvrState(string xcvr)
 		cmedia_gpio_line = defbuffer;
 		spref.get("cmedia_ptt", i, cmedia_ptt); cmedia_ptt = i;
 
+		spref.get("tmate2_device", defbuffer, "NONE", 499);
+		tmate2_device = defbuffer;
+		spref.get("tmate2_freq_step", defbuffer, "5000", 499);
+		tmate2_freq_step = defbuffer;
+		spref.get("tmate2_connected", i, tmate2_connected); tmate2_connected = i;
+
 		spref.get("poll_smeter", poll_smeter, poll_smeter);
 		spref.get("poll_frequency", poll_frequency, poll_frequency);
 		spref.get("poll_mode", poll_mode, poll_mode);
@@ -1287,6 +1368,11 @@ bool status::loadXcvrState(string xcvr)
 		spref.get("no_txqsy", no_txqsy, no_txqsy);
 
 		spref.get("schema", schema, schema);
+		spref.get("embed_tabs", embed_tabs, embed_tabs);
+		spref.get("show_tabs", show_tabs, show_tabs);
+
+		spref.get("visible_tab", defbuffer, visible_tab.c_str(), 499);
+		visible_tab = defbuffer;
 
 		spref.get("rx_avg", rx_avg, rx_avg);
 		spref.get("rx_peak", rx_peak, rx_peak);
@@ -1634,6 +1720,11 @@ bool status::loadXcvrState(string xcvr)
 		spref.get("peak_green", peakGreen, peakGreen);
 		spref.get("peak_blue", peakBlue, peakBlue);
 
+		spref.get("volt_red", voltRed, voltRed);
+		spref.get("volt_green", voltGreen, voltGreen);
+		spref.get("volt_blue", voltBlue, voltBlue);
+		spref.get("display_voltmeter", display_voltmeter, display_voltmeter);
+
 		spref.get("fg_sys_red", fg_sys_red, fg_sys_red);
 		spref.get("fg_sys_green", fg_sys_green, fg_sys_green);
 		spref.get("fg_sys_blue", fg_sys_blue, fg_sys_blue);
@@ -1658,6 +1749,10 @@ bool status::loadXcvrState(string xcvr)
 		spref.get("lighted_btn_green", lighted_btn_green, lighted_btn_green);
 		spref.get("lighted_btn_blue", lighted_btn_blue, lighted_btn_blue);
 
+		spref.get("tab_red", tab_red, tab_red);
+		spref.get("tab_green", tab_green, tab_green);
+		spref.get("tab_blue", tab_blue, tab_blue);
+
 		i = (int)fontnbr;
 		spref.get("fontnbr", i, i); fontnbr = (Fl_Font)i;
 		i = 0;
@@ -1804,6 +1899,29 @@ bool status::loadXcvrState(string xcvr)
 		spref.get("VE", defbuffer, VE.c_str(), 499);
 		VE = defbuffer;
 
+		spref.get("FSK_KEYLINE", FSK_KEYLINE, FSK_KEYLINE);
+		spref.get("FSK_SHARED", FSK_SHARED, FSK_SHARED);
+		spref.get("FSK_PTT", FSK_PTT, FSK_PTT);
+		spref.get("FSK_CONNECTED", FSK_CONNECTED, FSK_CONNECTED);
+		spref.get("FSK_INVERTED", FSK_INVERTED, FSK_INVERTED);
+		spref.get("FSK_STOPBITS", FSK_STOPBITS, FSK_STOPBITS);
+		spref.get("FSK_PORT", defbuffer, "NONE", 499);
+		FSK_PORT = defbuffer;
+
+		for (int n = 0; n < 12; n++) {
+			snprintf(getbuff, sizeof(getbuff), "fskiolabel[%d]", n);
+			spref.get(getbuff, defbuffer, "", 499);
+			FSK_labels[n] = defbuffer;
+			snprintf(getbuff, sizeof(getbuff), "fskiomessage[%d]", n);
+			spref.get(getbuff, defbuffer, "", 499);
+			FSK_msgs[n] = defbuffer;
+		}
+
+//std::cout << "LOAD STATUS\nx: " << mainX << ", y: " << mainY << ", w: " << mainW << " h: " << mainH << std::endl;
+//std::cout << "embed tabs: " << embed_tabs << std::endl;
+//std::cout << "show tabs : " << show_tabs << std::endl;
+//std::cout << "show controls: " << show_controls << std::endl << std::endl;
+
 		return true; 
 	}
 	return false;
@@ -1860,6 +1978,41 @@ void status::UI_laststate()
 	sldrSWR->color(fl_rgb_color (swrRed, swrGreen, swrBlue), bgclr);
 	sldrSWR->PeakColor(fl_rgb_color(peakRed, peakGreen, peakBlue));
 
+	sldrVoltage->color(fl_rgb_color (voltRed, voltGreen, voltBlue), bgclr);
+	sldrVoltage->PeakColor(bgclr);
+
+	scaleVoltage->color(bgclr);
+	scaleVoltage->labelcolor(fgclr);
+
+	mtr_SMETER->color(bgclr);
+	mtr_SMETER->labelcolor(fgclr);
+	sigbar_SMETER->color(fl_rgb_color (smeterRed, smeterGreen, smeterBlue), bgclr);
+	sigbar_SMETER->PeakColor(fl_rgb_color(peakRed, peakGreen, peakBlue));
+
+	mtr_PWR->color(bgclr);
+	mtr_PWR->labelcolor(fgclr);
+	sigbar_PWR->color(fl_rgb_color (pwrRed, pwrGreen, pwrBlue), bgclr);
+	sigbar_PWR->PeakColor(fl_rgb_color(peakRed, peakGreen, peakBlue));
+
+	mtr_SWR->color(bgclr);
+	mtr_SWR->labelcolor(fgclr);
+	sigbar_SWR->color(fl_rgb_color (swrRed, swrGreen, swrBlue), bgclr);
+	sigbar_SWR->PeakColor(fl_rgb_color(peakRed, peakGreen, peakBlue));
+
+	mtr_ALC->color(bgclr);
+	mtr_ALC->labelcolor(fgclr);
+	sigbar_ALC->color(fl_rgb_color (swrRed, swrGreen, swrBlue), bgclr);
+	sigbar_ALC->PeakColor(fl_rgb_color(peakRed, peakGreen, peakBlue));
+
+	mtr_VOLTS->color(bgclr);
+	mtr_VOLTS->labelcolor(fgclr);
+	sigbar_VOLTS->color(fl_rgb_color (voltRed, voltGreen, voltBlue), bgclr);
+	sigbar_VOLTS->PeakColor(bgclr);
+
+// set scale for both voltage display
+	sldrVoltage->minimum (6); sldrVoltage->maximum (16);
+	sigbar_VOLTS->minimum (6); sigbar_VOLTS->maximum (16);
+
 	if (UIsize != small_ui)
 		meter_fill_box->color(bgclr);
 
@@ -2158,8 +2311,8 @@ static bool srigtrace;
 static bool ssettrace;
 static bool sgettrace;
 
-void ss_trace(bool on) {
-
+void ss_trace(bool on)
+{
 	if (on) {
 		strace = progStatus.trace;
 		srigtrace = progStatus.rigtrace;
