@@ -48,40 +48,26 @@
 
 using namespace std;
 
-static int _zmsec = 0;
-static int _zsec = 0;
-static int _zmin = 0;
-static int _zhr = 0;
-
-void ztimer()
+size_t zmsec()
 {
-	struct tm tm;
-	time_t t_temp;
-	struct timeval tv;
-
+	static struct timeval tv;
 	gettimeofday(&tv, NULL);
-
-	t_temp=(time_t)tv.tv_sec;
-	gmtime_r(&t_temp, &tm);
-
-	_zmsec = tv.tv_usec / 1000;
-	_zsec = tm.tm_sec;
-	_zmin = tm.tm_min;
-	_zhr  = tm.tm_hour;
+	return (tv.tv_sec * 1000L + (tv.tv_usec / 1000L));
 }
 
-int zmsec(void)
-{
-	ztimer();
-	return _zmsec;
-}
-
-char exttime[13];
 char *ztime()
 {
-	ztimer();
+	static char exttime[13];
+
+	static struct tm tim;
+	static struct timeval tv;
+
+	gettimeofday(&tv, NULL);
+	gmtime_r(&tv.tv_sec, &tim);
+
 	snprintf(exttime, sizeof(exttime),
 		"%02d:%02d:%02d.%03d",
-		_zhr, _zmin, _zsec, _zmsec);
+		tim.tm_hour, tim.tm_min, tim.tm_sec, (int)(tv.tv_usec / 1000L) );
+
 	return exttime;
 }
